clx-20220630_d2

Exhibit 99.1
MANAGEMENT’S DISCUSSION AND ANALYSIS OF FINANCIAL CONDITION AND
RESULTS OF OPERATIONS
The Clorox Company
(Dollars in millions, except per share data)
Management’s Discussion and Analysis of Financial Condition and Results of Operations (MD&A) is designed to provide a reader of The Clorox Company’s (the Company or Clorox) financial statements with a narrative from the perspective of management on the Company’s financial condition, results of operations, liquidity and certain other factors that may affect future results. In certain instances, parenthetical references are made to relevant sections of the Notes to Consolidated Financial Statements to direct the reader to a further detailed discussion. This section should be read in conjunction with the Consolidated Financial Statements and Supplementary Data included in this Annual Report on Form 10-K.
The following sections are included herein:
•Executive Overview
•Results of Operations
•Financial Position and Liquidity
•Contingencies
•Quantitative and Qualitative Disclosures about Market Risk
•Recently Issued Accounting Standards
•Critical Accounting Estimates
•Summary of Non-GAAP Financial Measures
EXECUTIVE OVERVIEW
Clorox is a leading multinational manufacturer and marketer of consumer and professional products with fiscal year 2022 net sales of $7,107 and approximately 9,000 employees worldwide as of June 30, 2022. Clorox sells its products primarily through mass retailers, grocery outlets, warehouse clubs, dollar stores, home hardware centers, drug, pet and military stores, third-party and owned e-commerce channels and distributors. Clorox markets some of the most trusted and recognized consumer brand names, including its namesake bleach and cleaning products; Pine-Sol cleaners; Liquid-Plumr clog removers; Poett home care products; Fresh Step cat litter; Glad bags and wraps; Kingsford grilling products; Hidden Valley dressings, dips, seasonings and sauces; Brita water-filtration products; Burt’s Bees natural personal care products; and RenewLife, Rainbow Light, Natural Vitality and NeoCell vitamins, minerals and supplements. The Company also markets industry-leading products and technologies for professional customers, including those sold under the CloroxPro and Clorox Healthcare brand names. The Company has operations in more than 25 countries or territories and sells its products in more than 100 markets.
The Company primarily markets its leading brands in midsized categories considered to be financially attractive. Most of the Company’s products compete with other nationally advertised brands within each category and with “private label” brands.
The Company operates through strategic business units (SBUs) that are also the Company’s operating segments. These SBUs are then aggregated into four reportable segments: Health and Wellness, Household, Lifestyle and International. These four reportable segments consist of the following:
•Health and Wellness consists of cleaning products, professional products and vitamins, minerals and supplements mainly marketed and sold in the U.S. Products within this segment include cleaning products such as laundry additives and home care products, primarily under the Clorox, Clorox2, Scentiva, Pine-Sol, Liquid-Plumr, Tilex and Formula 409 brands; professional cleaning and disinfecting products under the CloroxPro and Clorox Healthcare brands; professional food service products under the Hidden Valley brand; and vitamins, minerals and supplements under the RenewLife, Natural Vitality, NeoCell and Rainbow Light brands.
•Household consists of bags and wraps, grilling products and cat litter marketed and sold in the U.S. Products within this segment include bags and wraps under the Glad brand; grilling products under the Kingsford brand; and cat litter primarily under the Fresh Step and Scoop Away brands.
•Lifestyle consists of food, natural personal care products and water-filtration products marketed and sold in the U.S. Products within this segment include dressings, dips, seasonings and sauces, primarily under the Hidden Valley brand; natural personal care products under the Burt’s Bees brand; and water-filtration products under the Brita brand.
1

•International consists of products sold outside the U.S. Products within this segment include laundry additives; home care products; water-filtration products; digestive health products; grilling products; cat litter; food; bags and wraps; natural personal care products; and professional cleaning and disinfecting products marketed primarily under the Clorox, Ayudin, Clorinda, Poett, Pine-Sol, Glad, Brita, RenewLife, Ever Clean and Burt’s Bees brands.
Non-GAAP Financial Measures
This Executive Overview, the succeeding sections of MD&A and Exhibit 99.2 may include certain financial measures that are not defined by accounting principles generally accepted in the United States of America (U.S. GAAP). These measures, which are referred to as non-GAAP measures, are listed below:
•Free cash flow and free cash flow as a percentage of net sales. Free cash flow is calculated as net cash provided by operations less capital expenditures.
•Earnings before interest and taxes (EBIT) margin (the ratio of EBIT to net sales)
•Economic profit (EP) is defined by the Company as earnings before income taxes, excluding certain U.S. GAAP items (such as asset impairments, charges related to digital capabilities and productivity enhancements investment, significant losses/(gains) related to acquisitions and other non-recurring or unusual items) and interest expense; less income taxes (calculated based on the Company’s effective tax rate excluding the identified U.S. GAAP items), and less after tax profit attributable to noncontrolling interests, and less a capital charge (calculated as average capital employed multiplied by a cost of capital rate).
•Organic sales growth / (decrease) is defined as net sales growth excluding the effect of foreign exchange rate changes and any acquisitions and divestitures.
For a discussion of these measures and the reasons management believes they are useful to investors, refer to “Summary of Non-GAAP Financial Measures” below. To the extent applicable, this MD&A and Exhibit 99.2 include reconciliations of these non-GAAP measures to the most directly comparable financial measures calculated and presented in accordance with U.S. GAAP.
Fiscal Year 2022 Financial Highlights
A detailed discussion of strategic goals, key initiatives and results of operations is included below. Key fiscal year 2022 financial results are summarized as follows:
•The Company’s fiscal year 2022 net sales decreased by 3% to $7,107 from $7,341 in fiscal year 2021, reflecting lower shipments primarily in the Health and Wellness reportable segment. The variance between volume and net sales was primarily due to the impact of favorable price mix, partially offset by unfavorable foreign currency exchange rates.
•Gross margin decreased by 780 basis points to 35.8% in fiscal year 2022 from 43.6% in fiscal year 2021. The decrease was primarily driven by higher manufacturing and logistics costs, increased commodity costs and unfavorable mix, partially offset by the benefit of price increases and cost savings.
•The Company reported earnings before income taxes of $607 in fiscal year 2022, compared to $900 in fiscal year 2021. The Company reported earnings attributable to Clorox of $462 in fiscal year 2022, compared to $710 in fiscal year 2021.
•The Company delivered diluted net earnings per share (EPS) of $3.73 in fiscal year 2022, a decrease of approximately 33%, or $1.85, from fiscal year 2021 diluted net EPS of $5.58. The decrease was primarily due to lower gross margin and the one-time, noncash remeasurement gain recognized on the previously held equity interest in the Saudi joint venture in the prior period, partially offset by the noncash impairment charges on assets held by the Vitamins, Minerals and Supplements (VMS) business in the prior period.
•EP decreased by 58% to $282 in fiscal year 2022, compared to $672 in fiscal year 2021 (refer to the reconciliation of EP to earnings before income taxes in Exhibit 99.2).
•The Company’s net cash provided by operations was $786 in fiscal year 2022, compared to $1,276 in fiscal year 2021. Free cash flow was $535 or 7.5% of net sales in fiscal year 2022, compared to $945 or 12.9% of net sales in fiscal year 2021 (refer to the reconciliation of net cash provided by operations to free cash flow in “Financial Position and Liquidity - Investing - Free Cash Flow”).
2

•The Company paid $571 in cash dividends to stockholders in fiscal year 2022, compared to $558 in cash dividends in fiscal year 2021. In July 2022, the Company announced an increase of 2% in its quarterly cash dividend from the prior year.
Strategic Goals and Initiatives
As announced in 2019, the IGNITE strategy is intended to accelerate innovation in key areas of the business to drive growth and deliver value for both the Company's shareholders and society. Specifically, IGNITE focuses on four strategic choices to deliver purpose-driven growth: Fuel Growth, Innovate Experiences, Reimagine Work and Evolve Portfolio. Performance goals within the environmental, social and governance pillars of Healthy Lives, Clean Planet and Thriving Communities, all underpinned by strong governance also are integrated into the strategy. The Company’s long-term financial goals reflected in IGNITE include annual net sales growth of 3% to 5% — increased from 2% to 4% in 2021 — annual EBIT margin expansion of 25 to 50 basis points and annual free cash flow of 11% to 13%.
Additionally, in fiscal year 2021 the Company announced a strategic investment of approximately $500 over a five-year period for digital capabilities and productivity enhancements. This investment, which began in the first quarter of fiscal year 2022, includes replacement of the Company's enterprise resource planning system and transitioning to a cloud-based platform as well as the implementation of a suite of other digital technologies. This investment will generate efficiencies and better position the Company in supply chain, digital commerce, innovation, brand building and more over the long term.
Recent Events Affecting the Company
For the fiscal year ended June 30, 2022, the effects of the on-going novel coronavirus (COVID-19) pandemic continued to cause economic and social disruptions. These disruptions led to ongoing uncertainties, heightened by the conflict in Ukraine that began in the back half of the fiscal year.
Demand for many of the products across the Company's portfolio remained elevated compared to pre-pandemic levels, but moderated versus the previous fiscal year. An inflationary environment marked by higher manufacturing and logistics costs as well as increased commodity costs is expected to continue into fiscal year 2023. While we did not experience significant disruptions in our operations during fiscal year 2022, the risks of future negative impacts due to transportation, logistical or supply constraints and higher commodity costs for certain raw materials remain present, and the Company continues to experience corresponding incremental costs and gross margin pressures.
Throughout fiscal year 2022, our focus has been on addressing supply-chain disruptions and volatility in commodity costs and foreign exchange markets and countering inflationary pressures through pricing actions and cost-cutting measures.
The extent of COVID-19’s effect on the Company’s operational and financial performance in the future will depend on future developments, including the duration, spread, intensity and phase of the pandemic in different countries, the emergence of COVID-19 variants and the effectiveness of vaccines against these variants, the Company’s continued ability to manufacture and distribute its products, any future government actions affecting consumers, our business operations, including any vaccine mandates, or the economy in general, and effectiveness of global vaccines. Additionally, the impact of certain geopolitical events, specifically the conflict in Ukraine, and continued inflationary pressures have increased global economic and political uncertainty due to the uncertainty around the duration and resolution of the conflict and potential economic and global supply chain disruptions. All of these factors are difficult to predict considering the rapidly evolving landscape as the Company continues to expect a variable operating environment going forward.
For further discussion of the possible impacts of the COVID-19 pandemic and other recent events on our business, financial conditions and results of operations, see “Risk Factors” in Part I, Item 1A of this Report.
3

RESULTS OF OPERATIONS
Unless otherwise noted, MD&A compares results of operations from fiscal year 2022 to fiscal year 2021, with percentage and basis point calculations based on rounded numbers, except for per share data and the effective tax rate. Discussions of fiscal year 2020 items and year-to-year comparisons between fiscal years 2021 and 2020 that are not included in this Annual Report on Form 10-K can be found in “Management’s Discussion and Analysis of Financial Condition and Results of Operations” in Exhibit 99.1 of the Company’s Annual Report on Form 10-K for the fiscal year ended June 30, 2021.
CONSOLIDATED RESULTS

|  |  |  |  | % Change
| 2022 |  | 2021 |  | 2022 to 2021
Net sales | $ | 7,107 |  |  | $ | 7,341 |  |  | (3) | %

| Year Ended June 30, 2022
| Percentage change versus the year-ago period
| Reported (GAAP) Net Sales Growth / (Decrease) | Reported Volume |  | Acquisitions & Divestitures | Foreign Exchange Impact | Price/Mix/Other (1) | Organic Sales Growth / (Decrease) (Non-GAAP) (2) | Organic Volume (3)
Health and Wellness | (10) | % | (9) | % |  | — | % | — | % | (1) | % | (10) | % | (9) | %
Household | — |  | (3) |  |  | — |  | — |  | 3 |  | — |  | (3) |
Lifestyle | 3 |  | 2 |  |  | — |  | — |  | 1 |  | 3 |  | 2 |
International | 2 |  | (1) |  |  | — |  | (4) |  | 7 |  | 6 |  | (1) |
Total | (3) | % | (5) | % |  | — | % | (1) | % | 3 | % | (2) | % | (5) | %

(1) This represents the net impact on net sales growth / (decrease) from pricing actions, mix and other factors.
(2) Organic sales growth / (decrease) is defined as net sales growth / (decrease) excluding the effect of any acquisitions and divestitures and foreign exchange rate changes. See “Summary of Non-GAAP Financial Measures” below for reconciliation of organic sales growth / (decrease) to net sales growth / (decrease), the most directly comparable GAAP financial measure.
(3) Organic volume represents volume excluding the effect of any acquisitions and divestitures.
Net sales in fiscal year 2022 decreased by 3%, reflecting lower shipments primarily in the Health and Wellness reportable segment. Volume decreased by 5% versus the prior period. The variance between volume and net sales was primarily due to the impact of favorable price mix, partially offset by unfavorable foreign currency exchange rates.

|  |  |  |  | % Change
| 2022 |  | 2021 |  | 2022 to 2021
Gross profit | $ | 2,545 |  |  | $ | 3,199 |  |  | (20) | %
Gross margin | 35.8 | % |  | 43.6 | % |  |

Gross margin decreased by 780 basis points in fiscal year 2022 from 43.6% to 35.8%. The decrease was primarily driven by higher manufacturing and logistics costs, increased commodity costs and unfavorable mix, partially offset by the benefit of price increases and cost savings.
4

Expenses

|  |  |  |  | % Change |  | % of Net sales
| 2022 |  | 2021 |  | 2022 to 2021 |  | 2022 |  | 2021
Selling and administrative expenses | $ | 954 |  |  | $ | 1,004 |  |  | (5) | % |  | 13.4 | % |  | 13.7 | %
Advertising costs | 709 |  |  | 790 |  |  | (10) |  |  | 10.0 |  |  | 10.8 |
Research and development costs | 132 |  |  | 149 |  |  | (11) |  |  | 1.9 |  |  | 2.0 |

Selling and administrative expenses, as a percentage of net sales, decreased by 30 basis points in fiscal year 2022. The dollar decrease in selling and administrative expenses was primarily due to lower nonqualified deferred compensation plan expense, lower incentive compensation expense and the benefit from cost savings, partially offset by the Company’s digital capabilities and productivity enhancements investments.
Advertising costs, as a percentage of net sales, decreased by 80 basis points in fiscal year 2022. The dollar decrease was primarily due to higher spend in the prior period and the Company returning to historical levels of spend in the current period. The Company’s U.S. retail advertising spend as a percentage of net sales was 10% for fiscal year 2022 and 12% for fiscal year 2021, respectively.
Research and development costs, as a percentage of net sales, were essentially flat in the current period as compared to the prior period. The Company continues to invest behind product innovation and cost savings.
Goodwill, trademark and other asset impairments, Interest expense, Other expense (income), net, and the effective tax rate on earnings

| 2022 |  | 2021
Goodwill, trademark and other asset impairments | $ | — |  |  | $ | 329 |
Interest expense | 106 |  |  | 99 |
Other expense (income), net | 37 |  |  | (72) |
Effective tax rate on earnings | 22.4% |  | 20.1 | %

Goodwill, trademark and other asset impairments of $329 in the prior fiscal year reflect non-cash impairment charges related to goodwill, trademarks, and other assets held by the VMS business (included within the Health and Wellness segment). See Notes to Consolidated Financial Statements for further information regarding the impairments recorded.
Interest expense was $106 and $99 in fiscal year 2022 and fiscal year 2021, respectively. The increase in the current period interest expense was primarily due to a loss on the early extinguishment of debt. See Notes to Consolidated Financial Statements for further information regarding the loss on the early extinguishment of debt recorded.
Other expense (income), net was $37 and ($72) in fiscal year 2022 and fiscal year 2021, respectively. The variance was due to the one-time, non-cash remeasurement gain recognized from the Company’s previously held equity interest in the Saudi joint venture in the first quarter of fiscal year 2021 (see Notes to Consolidated Financial Statements) and the loss in the current period from revaluation of the Company’s trust assets related to its nonqualified deferred compensations plans.
The effective tax rate on earnings (losses) was 22.4% and 20.1% in fiscal year 2022 and 2021, respectively. The lower tax rate in fiscal year 2021 compared to fiscal year 2022 was driven by higher excess tax benefits from stock-based compensation in the prior year.
Diluted net earnings per share

|  |  |  |  | % Change
| 2022 |  | 2021 |  | 2022 to 2021
Diluted net EPS | $ | 3.73 |  |  | $ | 5.58 |  |  | (33) | %

Diluted net earnings per share (EPS) decreased by 1.85, or 33%, in fiscal year 2022, primarily due to lower gross margin and the one-time, noncash remeasurement gain recognized on the previously held equity interest in the Saudi joint venture in the prior period, partially offset by the noncash impairment charges on assets held by the VMS business in the prior period.
5

SEGMENT RESULTS
The following presents the results of the Company’s reportable segments and certain unallocated costs reflected in Corporate (see Notes to Consolidated Financial Statements for a reconciliation of segment results to consolidated results):
Health and Wellness

|  |  |  |  | % Change
| 2022 |  | 2021 |  | 2022 to 2021
Net sales | $ | 2,690 |  |  | $ | 2,980 |  |  | (10) | %
Earnings before income taxes | 300 |  |  | 305 |  |  | (2) |

Fiscal year 2022 versus fiscal year 2021: Volume, net sales and earnings before income taxes decreased by 9%, 10% and 2%, respectively, during fiscal year 2022. The volume and net sales decreases were primarily due to lower shipments in the Professional Products portfolio due to higher COVID-19 related demand in the prior period. The decrease in earnings before income taxes in the current period was primarily due to lower net sales, higher manufacturing and logistics costs and unfavorable commodity costs, partially offset by the non-cash impairment charges on assets held by the VMS business in the prior period, and lower advertising spending, selling and administrative expenses and cost savings in the current period.
Household

|  |  |  |  | % Change
| 2022 |  | 2021 |  | 2022 to 2021
Net sales | $ | 1,984 |  |  | $ | 1,981 |  |  | — | %
Earnings before income taxes | 234 |  |  | 375 |  |  | (38) |

Fiscal year 2022 versus fiscal year 2021: Volume and earnings before income taxes decreased by 3% and 38%, respectively, and net sales were flat during fiscal year 2022. The volume decrease was primarily driven by lower shipments in Grilling due to higher demand in the prior period and impacts from pricing actions in the current period. The decrease in earnings before income taxes was mainly due to unfavorable commodity costs and higher manufacturing and logistics costs, partially offset by cost saving efforts and the benefits from pricing and lower trade spending.
Lifestyle

|  |  |  |  | % Change
| 2022 |  | 2021 |  | 2022 to 2021
Net sales | $ | 1,253 |  |  | $ | 1,218 |  |  | 3 | %
Earnings before income taxes | 280 |  |  | 320 |  |  | (13) |

Fiscal year 2022 versus fiscal year 2021: Volume and net sales increased by 2% and 3%, respectively, while earnings before income taxes decreased by 13% during fiscal year 2022. The volume and net sales increases were primarily driven by higher shipments of Brita water-filtration products due to expanded distribution and merchandising support and Natural Personal Care products primarily due to innovation and strong consumption. The decrease in earnings before income taxes was primarily due to unfavorable commodity costs and higher manufacturing and logistics costs, partially offset by net sales growth.
6

International

|  |  |  |  | % Change
| 2022 |  | 2021 |  | 2022 to 2021
Net sales | $ | 1,180 |  |  | $ | 1,162 |  |  | 2 | %
Earnings before income taxes | 97 |  |  | 201 |  |  | (52) |

Fiscal year 2022 versus fiscal year 2021: Volume and earnings before income taxes decreased by 1% and 52%, respectively, and net sales increased by 2% during fiscal year 2022. The variance between volume and net sales was mainly due to the benefit of price increases, partially offset by the impact of unfavorable foreign exchange rates. The decrease in earnings before income taxes was primarily due to the one-time, noncash remeasurement gain recognized on the previously held equity interest in the Saudi joint venture recognized in the prior period and unfavorable commodity costs and higher manufacturing and logistics costs, partially offset by net sales growth all in the current period.
Argentina
The business environment in Argentina continues to be challenging due to significant volatility in Argentina’s currency, high inflation, economic recession, impacts of COVID-19 and temporary price controls. The Company operates in Argentina through certain wholly owned subsidiaries (collectively, “Clorox Argentina”). Clorox Argentina manufactures products at two plants that it owns and operates across Argentina.
Effective July 1, 2018, under the requirements of U.S. GAAP, Argentina was designated as a highly inflationary economy, and as a result, the U.S. dollar replaced the Argentine peso as the functional currency of the Company’s subsidiaries in Argentina. Consequently, gains and losses from non-U.S. dollar denominated monetary assets and liabilities of Clorox Argentina are recognized in Other (income) expense, net in the consolidated statement of earnings.
As of September 2019, the government of Argentina reinstated foreign exchange controls in response to further declines in the value of the Argentine peso, limiting the Company’s ability to convert Argentine pesos to U.S. dollars and transfer U.S. dollars outside of Argentina. As of June 30, 2022 and 2021, the net asset position, excluding goodwill, of Clorox Argentina was $45 and $48, respectively. Of these net assets, cash balances were approximately $15 and $11 as of June 30, 2022 and 2021, respectively. Net sales from Clorox Argentina represented approximately 2% of the Company’s consolidated net sales for the fiscal years ended June 30, 2022 and 2021.
Volatility in the exchange rate is expected to continue, which, along with competition, changes in the retail, labor and macro-economic environment, and implemented and future additional legal limitations instituted to restrict foreign exchange transactions, as well as government price controls, could have an adverse impact on Clorox Argentina’s liquidity, net sales, net earnings, cash flows and net monetary asset position. The Company is closely monitoring developments in Argentina and continues to take steps intended to mitigate the adverse conditions, but there can be no assurances that these actions will be able to mitigate these conditions as they may occur.
Corporate

|  |  |  |  | % Change
| 2022 |  | 2021 |  | 2022 to 2021
Losses before income taxes | $ | (304) |  |  | $ | (301) |  |  | 1 | %

Corporate includes certain non-allocated administrative costs, interest income, interest expense and various other non-operating income and expenses. Beginning in fiscal year 2022, losses before income taxes for Corporate include expenses related to the Company's digital capabilities and productivity enhancements investment.
Fiscal year 2022 versus fiscal year 2021: Losses before income taxes were essentially flat due to increased investments in the Company’s digital capabilities and productivity enhancements, offset by lower employee incentive compensation expenses.
7

FINANCIAL POSITION AND LIQUIDITY
Management’s discussion and analysis of the Company’s financial position and liquidity describes its consolidated operating, investing and financing activities from operations.
The Company’s cash position includes amounts held by foreign subsidiaries and, as a result, the repatriation of certain cash balances from some of the Company’s foreign subsidiaries could result in additional tax costs. However, these cash balances are generally available without legal restriction to fund local business operations. In addition, a portion of the Company’s cash balance is held in U.S. dollars by foreign subsidiaries, whose functional currency is their local currency. Such U.S. dollar balances are reported on the foreign subsidiaries’ books, in their functional currency, with the impact from foreign currency exchange rate differences recorded in Other (income) expense, net.
The Company’s financial condition and liquidity remained strong as of June 30, 2022. The following table summarizes cash activities for the years ended June 30:

| 2022 |  | 2021
Net cash provided by operations | $ | 786 |  |  | $ | 1,276 |
Net cash used for investing activities | (229) |  |  | (452) |
Net cash used for financing activities | (689) |  |  | (1,391) |

Operating Activities
Net cash provided by operations was $786 in fiscal year 2022, compared with $1,276 in fiscal year 2021. The year-over-year decrease was driven by lower cash earnings and an increase in working capital, partially offset by lower tax payments and cash received from the settlement of interest rate derivative contracts in the current period. The increase in working capital was due to lower Accounts payable and accrued liabilities in the current period driven by lower spend and timing of payments, higher receivables due to the timing of sales in the current period and increased collections in the prior period, partially offset by higher inventory builds in the prior period to improve product availability.
Payment Terms Extension and Supply Chain Financing
The Company initiated the extension of its payment terms with its suppliers in the second half of fiscal year 2020 in order to improve working capital as part of and to fund the IGNITE strategy and in keeping with evolving market practices. The Company’s current payment terms do not exceed 120 days in keeping with industry standards. The Company’s operating cash flows are directly impacted as a result of the extension of the payment terms with the suppliers.
As part of those ongoing efforts, the Company has arranged for a global financial institution to offer a voluntary supply chain finance (SCF) program for the benefit of the Company’s suppliers. Leveraging the Company’s credit rating, the SCF program enables suppliers to directly contract with the financial institution to receive payment from the financial institution prior to the payment terms between the Company and the supplier, by selling the Company’s payables to the financial institution. The participation in the program is at the sole discretion of the supplier and the Company has no economic interest in a supplier's decision to enter into the agreement and has no direct financial relationship with the financial institution, as it relates to the SCF program. Once a supplier elects to participate in the SCF program and reaches an agreement with the financial institution, the supplier elects which individual Company invoices to sell to the financial institution. The terms of the Company’s payment obligations are not impacted by a supplier’s participation in the program and as such, the SCF program has no direct impact on the Company’s balance sheets, cash flows or liquidity. No guarantees are provided by the Company or any of our subsidiaries under the SCF program. There would not be an expected material impact to the Company’s liquidity or capital resources if the financial institution or a supplier terminated the SCF arrangement.
All outstanding amounts related to suppliers participating in SCF are recorded within Accounts payable and accrued liabilities in the Consolidated Balance Sheets and the associated payments are included in operating activities within the Consolidated Statements of Cash Flows. As of June 30, 2022 and 2021, the amount due to suppliers participating in SCF and included in Accounts payable and accrued liabilities was $211 and $152, respectively. While the Company does not have direct access to information on, or influence over, which invoices a participating supplier elects to sell to the financial institution, the Company expects that the majority of these amounts have been sold to the financial institution.
Investing Activities
Net cash used for investing activities was $229 in fiscal year 2022, as compared to $452 in fiscal year 2021. The year-over-year decrease was mainly due to the acquisition of additional interest in the Company's Saudi joint venture in the prior period and lower capital spending in the current period.
8

Capital expenditures were $251 and $331 in fiscal years 2022 and 2021, respectively. Capital expenditures as a percentage of net sales was 3.5% and 4.5% for fiscal years 2022 and 2021, respectively. The current year-over-year decrease was due to higher spending in the prior period on capital projects to expand production capacity.
Free cash flow

| 2022 |  | 2021
Net cash provided by operations | $ | 786 |  |  | $ | 1,276 |
Less: capital expenditures | (251) |  |  | (331) |
Free cash flow | $ | 535 |  |  | $ | 945 |
Free cash flow as a percentage of net sales | 7.5 | % |  | 12.9 | %

Financing Activities
Net cash used for financing activities was $689 in fiscal year 2022, compared with $1,391 in fiscal year 2021. The year-over-year decrease was mainly due to lower treasury stock purchases, partially offset by reduced proceeds from employee stock option exercises and net cash outflows from borrowings in the current period.
Current period financing activities include repayment of $300 of the Company’s senior notes with an annual fixed interest rate of 3.80% that became due in November 2021 and were repaid using commercial paper borrowings and repayment of $600 of the Company’s senior notes with an annual fixed interest rate of 3.05% due in September 2022 and $500 of senior notes with an annual fixed interest rate of 3.50% due in December 2024 that were redeemed prior to maturity using the proceeds from the May 2022 debt issuance of $1,100.
Capital Resources and Liquidity
The Company's current liabilities may periodically exceed current assets as a result of the Company's debt management policies, including the Company's use of commercial paper borrowings which fluctuates depending on the amount and timing of operating and investing cash flows and payments for shareholder transactions such as dividends. In addition, the Company’s cash generated from operations has decreased recently primarily due to higher manufacturing and logistics costs and unfavorable commodity costs. The Company continues to take actions to address some of the effects of such cost increases, which include implementing price increases, driving cost savings and optimizing the Company’s supply chain.
Global financial markets have experienced a significant increase in volatility due to heightened uncertainty over the adverse economic impact caused by the COVID-19 outbreak and other geopolitical circumstances. Notwithstanding potential unforeseen adverse market conditions and as part of the Company’s regular assessment of its cash needs, the Company believes it will have the funds necessary to support our short- and long-term liquidity and operating needs based on our anticipated ability to generate positive cash flows from operations in the future, access to capital markets enabled by our strong short-term and long-term credit ratings, and current borrowing availability.
The Company may consider other transactions that require the issuance of additional long- and/or short-term debt or other securities to finance acquisitions, repurchase stock, refinance debt or fund other activities for general business purposes. Such transactions could require funds in excess of the Company’s current cash levels and available credit lines, and the Company’s access to or cost of such additional funds could be adversely affected by any decrease in credit ratings, which were the following as of June 30:

| 2022 |  | 2021
| Short-term |  | Long-term |  | Short-term |  | Long-term
Standard and Poor’s | A-2 |  | BBB+ |  | A-2 |  | A-
Moody’s | P-2 |  | Baa1 |  | P-2 |  | Baa1

Credit Arrangements
On March 25, 2022, the Company entered into a new $1,200 revolving credit agreement (the Credit Agreement) that matures in March 2027. The Credit Agreement replaced a prior $1,200 revolving credit agreement (the prior Credit Agreement) in place since November 2019. The Credit Agreement also changed the interest rate benchmark used as a reference rate for certain borrowings under the Credit Agreement from the London Interbank Offered Rate (LIBOR) to the secured overnight financing rate (SOFR). The Company did not incur any termination fees or penalties in connection with entering the new Credit
9

Agreement, which was considered a debt modification. There were no borrowings under either the new Credit Agreement or the prior Credit Agreement as of June 30, 2022 and 2021, respectively, and the Company believes that borrowings under the new Credit Agreement are and will continue to be available for general corporate purposes. The Credit Agreement includes certain restrictive covenants and limitations. The primary restrictive covenant is a minimum ratio of 4.0, calculated as total earnings before interest, taxes, depreciation and amortization and other similar non-cash charges and certain other items (Consolidated EBITDA) to total interest expense for the trailing four quarters (Interest Coverage ratio), as defined and described in the Credit Agreement.
The Company was in compliance with all restrictive covenants and limitations in the Credit Agreement as of June 30, 2022, and anticipates being in compliance with all restrictive covenants for the foreseeable future.
As of June 30, 2022, the Company maintained $34 of foreign and other credit lines, of which $4 was outstanding and the remainder of $30 was available for borrowing.
As of June 30, 2021, the Company maintained $35 of foreign and other credit lines, of which $5 was outstanding and the remainder of $30 was available for borrowing.
Short-term Borrowings
The Company’s notes and loans payable primarily consist of U.S. commercial paper issued by the parent company and any borrowings under the Credit Agreement. These short-term borrowings have stated maturities of less than one year and provide supplemental funding for supporting operations. The level of U.S. commercial paper borrowings generally fluctuates depending upon the amount and timing of operating cash flows and payments for items such as dividends, income taxes, stock repurchases and pension contributions. The average balance of short-term borrowings outstanding was $233 and $0 for the fiscal years ended June 30, 2022 and 2021, respectively.
Long-term Borrowings
In May 2022, the Company issued $1,100 in senior notes, including $500 of senior notes with an annual fixed interest rate of 4.40% payable semi-annually in May and November, final maturity in May 2029 that carry an effective rate of 3.89% (May 2029 senior notes), which includes the impact from the settlement of interest rate contracts in May 2022, and $600 of senior notes with an annual fixed rate of 4.60%, payable semi-annually in May and November, final maturity in May 2032 that carry an effective rate of 3.25% (May 2032 senior notes), which includes the impact from the settlement of interest rate contracts in May 2022. The notes rank equally with all of the Company's existing senior indebtedness. Proceeds from the senior notes were used to redeem prior to maturity $600 of senior notes with an annual fixed interest rate of 3.05% due in September 2022 and $500 of senior notes with an annual fixed interest rate of 3.50% due in December 2024, which were redeemed in June 2022 and for general corporate purposes. In connection with the redemption prior to maturity of the $500 of senior notes due in December 2024, the Company recorded a loss on the early extinguishment of debt of $13, which is included in Interest expense in the Consolidated Statement of Earnings, representing the difference paid in cash between the redemption price and the carrying amount of the debt extinguished of $5 and the accelerated amortization of losses on settlement of interest rate contracts and issuance costs associated with the debt extinguished of $8.
In November 2021, $300 of the Company’s senior notes with annual fixed interest rate of 3.80% became due and were repaid using commercial paper borrowings.
Stock Repurchases and Dividend Payments
As of June 30, 2022, the Company had two stock repurchase programs: an open-market purchase program with an authorized aggregate purchase amount of up to $2,000, which has no expiration date and was authorized by the Board of Directors in May 2018, and a program to offset the anticipated impact of dilution related to stock-based awards (the Evergreen Program), which has no authorization limit on the dollar amount and no expiration date. During the twelve months ended June 30, 2022 and 2021, the Company purchased 152 thousand and 4,758 thousand shares of common stock at a cost of $25 and $905, respectively.
10

Dividends per share and total dividends paid to Clorox stockholders were as follows during the fiscal years ended June 30:

| 2022 |  | 2021
Dividends per share declared | $ | 3.48 |  |  | $ | 4.49 |
Dividends per share paid | 4.64 |  |  | 4.44 |
Total dividends paid | 571 |  |  | 558 |

On July 12, 2022, the Company declared a 2% increase in the quarterly dividend, from $1.16 to $1.18 per share, payable on August 12, 2022 to common stockholders of record as of the close of business on July 27, 2022.
On June 2, 2021, the Company declared a 5% increase in the quarterly dividend, from $1.11 to $1.16 per share, payable on August 13, 2021 to common stockholders of record as of the close of business on July 28, 2021.
Material Cash Requirements
The following table summarizes the Company’s current and long-term material cash requirements as of June 30, 2022, which we intend to fund primarily with operating cash flows:

| 2023 |  | 2024 |  | 2025 |  | 2026 |  | 2027 |  | Thereafter |  | Total
Long-term debt maturities including interest payments | $ | 90 |  |  | $ | 90 |  |  | $ | 90 |  |  | $ | 90 |  |  | $ | 90 |  |  | $ | 2,737 |  |  | $ | 3,187 |
Notes and loans payable | 265 |  |  | 1 |  |  | 1 |  |  | 1 |  |  | 1 |  |  | — |  |  | 269 |
Purchase obligations (1) | 186 |  |  | 127 |  |  | 73 |  |  | 35 |  |  | 12 |  |  | 23 |  |  | 456 |
Operating and finance leases | 87 |  |  | 83 |  |  | 70 |  |  | 57 |  |  | 46 |  |  | 103 |  |  | 446 |
Payments related to nonqualified retirement income and retirement health care plans (2) | 15 |  |  | 15 |  |  | 14 |  |  | 15 |  |  | 14 |  |  | 62 |  |  | 135 |
Venture Agreement terminal obligation (3) | — |  |  | — |  |  | — |  |  | 635 |  |  | — |  |  | — |  |  | 635 |
Total | $ | 643 |  |  | $ | 316 |  |  | $ | 248 |  |  | $ | 833 |  |  | $ | 163 |  |  | $ | 2,925 |  |  | $ | 5,128 |

(1)Purchase obligations are defined as purchase agreements that are enforceable and legally binding and that contain specified or determinable significant terms, including quantity, price and the approximate timing of the transaction. For purchase obligations subject to variable price and/or quantity provisions, an estimate of the price and/or quantity has been made. Examples of the Company’s purchase obligations include contracts to purchase raw materials, commitments to contract manufacturers, commitments for information technology and related services, advertising contracts, capital expenditure agreements, software acquisition and license commitments and service contracts. The raw material contracts included above are entered into during the regular course of business based on expectations of future purchases. Many of these raw material contracts are flexible to allow for changes in the Company’s business and related requirements. If such changes were to occur, the Company believes its exposure could differ from the amounts listed above. Any amounts reflected in the consolidated balance sheets as Accounts payable and accrued liabilities are excluded from the table above, as they are short-term in nature and expected to be paid within one year.
(2)These amounts represent expected payments through 2032. Based on the accounting rules for nonqualified retirement income and retirement health care plans, the liabilities reflected in the Company’s consolidated balance sheets differ from these expected future payments (see Notes to Consolidated Financial Statements).
(3)The Company has a venture agreement with The Procter & Gamble Company (P&G) for the Company’s Glad bags and wraps business (the Venture Agreement). As of June 30, 2022, P&G had a 20% interest in the venture. Upon termination of the agreement in January 2026, the Company is required to purchase P&G’s 20% interest for cash at fair value as established by predetermined valuation procedures. Refer to the Notes to Consolidated Financial Statements for further details.
As announced in fiscal year 2021 and with investments beginning in fiscal year 2022, Clorox plans to invest approximately $500 million over a five year period in its digital capabilities and for productivity enhancements. The above table includes contracted spend related to these investments within Purchase obligations, which are expected to be funded through cash generated from operations.
CONTINGENCIES
A summary of contingencies is contained in the Notes to Consolidated Financial Statements and is incorporated herein by reference.
11

QUANTITATIVE AND QUALITATIVE DISCLOSURES ABOUT MARKET RISK
As a multinational company, the Company is exposed to the impact of changes in commodity prices, foreign currency fluctuations, interest-rate risk and other types of market risk.
In the normal course of business, where available at a reasonable cost, the Company manages its exposure to market risk using contractual agreements and a variety of derivative instruments. The Company’s objective in managing its exposure to market risk is to limit the impact of fluctuations on earnings and cash flow through the use of derivative instruments, including over-the-counter swaps, forward purchase contracts and exchange-traded futures contracts. Over-the-counter derivative contracts are entered into for non-trading purposes with major credit-worthy institutions, thereby decreasing the risk of credit loss.
The Company uses different methodologies, when necessary, to estimate the fair value of its derivative contracts. The estimated fair values of the majority of the Company’s contracts are based on quoted market prices, exchange-traded market prices or broker price quotations, and represent the estimated amounts that the Company would pay or receive to terminate the contracts.
See Notes to Consolidated Financial Statements for further discussion of derivatives and hedging policies and fair value measurements.
Sensitivity Analysis for Derivative Contracts
For fiscal years 2022 and 2021, the Company’s exposure to market risk was estimated using sensitivity analyses, which illustrates the change in the fair value of a derivative financial instrument assuming hypothetical changes in commodity prices, foreign exchange rates or interest rates. The results of the sensitivity analyses for commodity, foreign currency and interest rate derivative contracts are summarized below. Actual changes in commodity prices, foreign exchange rates or interest rates may differ from the hypothetical changes, and any changes in the fair value of the contracts, real or hypothetical, would be partly to fully offset by an inverse change in the value of the underlying hedged items.
The changes in the fair value of derivatives are recorded as either assets or liabilities in the consolidated balance sheets with an offset to Net earnings or Other comprehensive (loss) income, depending on whether or not, for accounting purposes, the derivative is designated and qualified as an accounting hedge. For those derivative instruments designated and qualifying as hedging instruments, the Company must designate the hedging instrument either as a fair value hedge or as a cash flow hedge. The Company designates its commodity swaps and futures contracts for forecasted purchases of raw materials, foreign currency forward contracts for forecasted purchases of inventory, and interest rate contracts for forecasted interest payments as cash flow hedges. During the fiscal years ended June 30, 2022 and 2021, the Company had no hedging instruments designated as fair value hedges. In the event the Company has contracts not designated as hedges for accounting purposes, the Company recognizes the changes in the fair value of these contracts in the consolidated statement of earnings.
Commodity Price Risk
The Company is exposed to changes in the price of commodities used as raw materials in the manufacturing of its products. The Company uses various strategies, where available at a reasonable cost to manage cost exposures on certain raw material purchases with the objective of obtaining more predictable costs for these commodities, including long-term commodity purchase contracts and commodity derivative contracts. During fiscal years 2022 and 2021, the Company had derivative contracts related to raw material exposures for soybean oil used for the Food business and jet fuel used for the Grilling business.
Based on a hypothetical decrease or increase of 10% in these commodity prices as of June 30, 2022, and June 30, 2021, the estimated fair value of the Company’s then-existing commodity derivative contracts would decrease or increase by $3 and $4, respectively, with the corresponding impact included in Other comprehensive (loss) income.
Foreign Currency Risk
The Company seeks to minimize the impact of certain foreign currency fluctuations by hedging transactional exposures related to inventory purchases with foreign currency forward contracts. Based on a hypothetical decrease of 10% in the value of the U.S. dollar as of June 30, 2022 and June 30, 2021, the estimated fair value of the Company’s then-existing foreign currency derivative contracts would decrease by $3 and $8, respectively, with the corresponding impact included in Other comprehensive (loss) income. Based on a hypothetical increase of 10% in the value of the U.S. dollar as of June 30, 2022 and June 30, 2021, the estimated fair value of the Company’s then-existing foreign currency derivative contracts would increase by $3 and $6, respectively.
12

Interest Rate Risk
The Company can be exposed to interest rate volatility with regard to short-term borrowings, using commercial paper or under the Credit Agreement, in addition to potential changes in interest rates relating to anticipated future issuances of long-term debt. Weighted average interest rates for short-term borrowings using commercial paper were 0.48% during fiscal year 2022. The Company had no material exposure to interest rate volatility through any short-term borrowing arrangements during fiscal year 2021. Assuming average commercial paper borrowing levels during fiscal year 2022, a 100 basis point increase in interest rates or a decrease in interest rates to zero would increase or decrease interest expense from short-term borrowings by approximately $2 and $1, respectively.
The Company can also be exposed to interest rate volatility with regard to anticipated future issuances of debt. The Company utilizes interest rate contracts to manage our exposure to interest rate volatility related to movements in U.S. Treasury and swap rates. In May 2022, the Company’s interest rate contracts were settled upon issuance of $1,100 in senior notes. Therefore, as of June 30, 2022, the Company had no outstanding interest rate contracts. Based on a hypothetical increase or decrease of 100 basis points to relevant interest rates as of June 30, 2021, the estimated fair value of the Company’s existing interest rate contracts would have increased or decreased by $27 during fiscal year 2021, with the corresponding impact recorded in Other comprehensive (loss) income.
RECENTLY ISSUED ACCOUNTING STANDARDS
A summary of all recently issued accounting standards is contained in Note 1 of the Notes to Consolidated Financial Statements.
CRITICAL ACCOUNTING ESTIMATES
The methods, estimates and judgments the Company uses in applying its most critical accounting policies have a significant impact on the results the Company reports in its consolidated financial statements. Accordingly, a different financial presentation could result depending on the judgments, estimates or assumptions that are used. The most critical accounting estimates are those that are most important to the portrayal of the Company’s financial condition and results, and require the Company to make the most difficult and subjective judgments, often estimating the outcome of future events that are inherently uncertain. The Company’s most critical accounting estimates are related to:
•Revenue recognition;
•The valuation of goodwill and other intangible assets;
•Income taxes; and
•The Venture Agreement terminal obligation.
The Company’s critical accounting estimates have been reviewed with the Audit Committee of the Board of Directors. A summary of the Company’s significant accounting policies is contained in Note 1 of Notes to Consolidated Financial Statements.
13

Revenue Recognition
The Company’s revenue is primarily generated from the sale of finished products to customers. This revenue is reported net of certain variable consideration provided to customers, generally in the form of one-time and ongoing trade-promotion programs. These trade-promotion programs include shelf price reductions, in-store merchandising, consumer coupons and other trade-related activities. Amounts accrued for trade-promotions are based on various factors such as contractual terms and sales volumes, and also incorporate estimates that include customer participation rates, the rate at which customers will achieve program performance criteria, product availability and historical consumer redemption rates. The actual amounts remitted to customers for these activities may differ from the Company’s estimates, depending on how actual results of the programs compare to the estimates. If the Company’s trade promotion accrual estimates as of June 30, 2022 were to increase or decrease by 10%, the impact on net sales would be approximately $19.
Goodwill and Other Intangible Assets
The Company tests its goodwill and other indefinite-lived intangible assets for impairment annually in the fiscal fourth quarter unless there are indications during a different interim period that these assets may have become impaired.
Goodwill
For fiscal year 2022, the Company’s reporting units for goodwill impairment testing purposes were its individual SBUs. These reporting units, which are also the Company’s operating segments, are the level at which discrete financial information is available and reviewed by the manager of the respective operating segments. The respective operating segment managers, who have responsibility for operating decisions, allocating resources and assessing performance within their respective segments, do not review financial information for components that are below the operating segment level.
In its evaluation of goodwill impairment, the Company has the option to first assess qualitative factors such as the maturity and stability of the reporting unit, the magnitude of the excess fair value over the carrying value from a prior period’s impairment testing, other reporting unit operating results, micro and macroeconomic factors, as well as new events and circumstances impacting the operations at the reporting unit level. If the test indicates a potential for impairment, a quantitative test is performed. In the quantitative test, the Company compares the estimated fair value of each reporting unit to its carrying value. If the estimated fair value of any reporting unit is less than its carrying value, an impairment charge is recorded for the difference between the carrying value and the fair value of the reporting unit.
Determining the fair value of a reporting unit requires significant judgments, assumptions and estimates by management which are subject to uncertainty. The Company uses a discounted cash flow (DCF) method under the income approach for its quantitative test, as it believes that this approach is the most reliable indicator of the fair value of its businesses and the fair value of their future earnings and cash flows. Under this approach, the Company estimates the future cash flows of each reporting unit and discounts these cash flows at a rate of return that reflects their relative risk. The cash flows used in the DCF method are consistent with those the Company uses in its internal planning, which gives consideration to actual business trends experienced and the long-term business strategy. The other key estimates and factors used in the DCF method include, but are not limited to, net sales and expense growth rates, commodity prices, foreign exchange rates, inflation and a terminal growth rate. Future changes in the judgments, assumptions and estimates that are used in the impairment testing for goodwill could result in significantly different estimates of the fair values and future impairment charges.
During the third quarter of fiscal year 2021, as a result of lower than expected actual and projected net sales growth and operating performance for the VMS reporting unit, a strategic review was initiated by management that resulted in updated financial and operational plans. These events were considered a triggering event requiring interim impairment assessments to be performed on the VMS reporting unit, indefinite-lived trademarks and other assets. Based on the outcome of these assessments, a $228 goodwill impairment charge was recorded during the third quarter of fiscal year 2021. The results of the fiscal year 2022 annual impairment review indicated that the VMS reporting unit has a heightened risk of future impairments if any assumptions, estimates or market factors unfavorably change in the future. For perspective, if the discount rate as of June 30, 2022 were to increase by 100 basis points, the change to the estimated fair value of the VMS reporting unit would have resulted in impairment charges of approximately $10. No triggering events or impairments for goodwill related to the VMS reporting unit were identified during fiscal year 2022. The VMS reporting unit had goodwill of $306 as of June 30, 2022. The Company is closely monitoring any events, circumstances or changes in this business that might imply a further reduction in the estimated fair value and may lead to additional goodwill impairment.
Except for the VMS reporting unit discussed above, no heightened risk of impairment of reporting units was identified. No impairments were identified in fiscal year 2022 as a result of the Company’s impairment review performed annually during the fourth quarter or during any other quarters of fiscal year 2022.
14

Trademarks and Other Indefinite-Lived Intangible Assets
For trademarks and other intangible assets with indefinite lives, the Company has the option to first assess qualitative factors, such as the maturity and stability of the trademark or other intangible asset, the magnitude of the excess fair value over carrying value from a prior period’s impairment testing, other specific operating results, as well as new events and circumstances impacting the significant inputs used to determine the fair value of the intangible asset. If the result of a qualitative test indicates that it is more likely than not that the asset is impaired, a quantitative test is performed. When a quantitative test is performed, the estimated fair value of an asset is compared to its carrying value. If the carrying value of such asset exceeds its estimated fair value, an impairment charge is recorded for the difference between the carrying value and the estimated fair value. The Company uses a DCF method under the relief from royalty income approach to estimate the fair value of its trademarks and other intangible assets with indefinite lives. This approach requires significant judgments in determining the royalty rates and the assets’ estimated cash flows, including consideration of related net sales growth rates, as well as the appropriate discount and foreign exchange rates applied to those cash flows to determine fair value. Future changes in such estimates or the use of alternative assumptions could result in significantly different estimates of the fair values.
During the third quarter of fiscal year 2021, as a result of the interim impairment assessments performed on various VMS assets, an $86 impairment charge to indefinite-lived trademarks was recorded.
No heightened risk of impairment or impairments were identified in fiscal year 2022 as a result of the Company’s impairment review performed annually during the fourth quarter or during any other quarters of fiscal year 2022.
Finite-Lived Intangible Assets
Finite-lived intangible assets are reviewed for possible impairment whenever events or changes in circumstances occur that indicate that the carrying value of an asset (or asset group) may not be recoverable. The Company’s impairment review requires significant judgment by management, including estimating the future success of product lines, future sales volumes, revenue and expense growth rates, alternative uses for the assets and proceeds from the disposal of the assets. The Company reviews business plans for possible impairment indicators. The risk of impairment is initially assessed based on an estimate of the undiscounted cash flows at the lowest level for which identifiable cash flows exist. The asset (or asset group) is not recoverable when the carrying value of the asset exceeds the estimated future undiscounted cash flows generated by the asset. When impairment is indicated, an impairment charge is recorded for the difference between the asset’s (or asset group’s) carrying value and its estimated fair value. Depending on the asset, estimated fair value may be determined either by use of a DCF method or, if available, by reference to estimated selling values of assets in similar condition. These approaches require significant judgments in determining the assumptions utilized in the DCF or the selection of comparable assets, as applicable. Future changes in such estimates or the use of alternative assumptions could result in significantly different estimates of the fair values.
During the third quarter of fiscal year 2021, as a result of the interim impairment assessments performed on various VMS assets, a $14 impairment charge to finite-lived intangible assets was recorded. Additionally during the fourth quarter of fiscal year 2021, an impairment charge of $14 was recorded related to other intangible assets with finite lives that were no longer expected to be recoverable due to a pending exit from a Professional Products SBU supplier relationship.
No significant impairments for finite-lived intangible assets were identified in fiscal year 2022.
15

Income Taxes
The Company’s effective tax rate is based on income by tax jurisdiction, statutory tax rates and tax planning opportunities available to the Company in the various jurisdictions in which the Company operates. Significant judgment is required in determining the Company’s effective tax rate and in evaluating its tax positions.
The Company maintains valuation allowances when it is likely that all or a portion of a deferred tax asset will not be realized. Changes in valuation allowances from period to period are included in the Company’s income tax provision in the period of change. In determining whether a valuation allowance is warranted, the Company takes into account many factors, including the specific tax jurisdiction, both historical and projected future earnings, carryback and carryforward periods and tax planning strategies. Many of the judgments made in adjusting valuation allowances involve assumptions and estimates that are highly subjective. Valuation allowances maintained by the Company relate mostly to deferred tax assets arising from the Company’s currently anticipated inability to use net operating losses and tax credits in certain foreign countries.
In addition to valuation allowances, the Company establishes uncertain tax positions when such tax positions do not meet certain recognition thresholds or measurement standards as defined by generally accepted accounting principles. These uncertain tax positions are adjusted as a result of changes in factors such as tax legislation, interpretations of laws by courts, rulings by tax authorities, new audit developments, changes in estimates and the expiration of the statute of limitations. Amounts for uncertain tax positions are adjusted in quarters when new information becomes available or when positions are effectively settled. Many of the judgments made in adjusting uncertain tax positions involve assumptions and estimates regarding audit outcomes and the timing of audit settlements, which are often uncertain and subject to change.
Venture Agreement Terminal Obligation
The Company has a Venture Agreement with P&G for the Company’s Glad bags and wraps business. As of June 30, 2022 and June 30, 2021, P&G had a 20% interest in the venture. Upon termination of the agreement, currently set for January 2026, unless the parties agree to a further extension, the Company is required to purchase P&G’s 20% interest for cash at fair value as established by predetermined valuation procedures. The Company’s obligation to purchase P&G’s interest is reflected in Other liabilities. The difference between the estimated fair value and the amount recognized, and any future changes in the fair value of P&G’s interest, is charged to Cost of products sold in accordance with the effective interest method over the remaining life of the agreement. See Notes to Consolidated Financial Statements for additional information on the Venture Agreement.
The estimated fair value of P&G’s interest may increase or decrease up until any such purchase by the Company of P&G’s interest. The Company uses the DCF method under the income approach to estimate the fair value of P&G’s interest. Under this approach, the Company estimates the future cash flows and discounts these cash flows at a rate of return that reflects its risk. The cash flows used are consistent with those the Company uses in its internal planning, which gives consideration to actual business trends experienced and the long-term business strategy. The other key assumptions and estimates used include, but are not limited to, net sales and expense growth rates, commodity prices, foreign exchange rates, discount rates, inflation and terminal growth rates. Fair value determination requires significant judgment, assumptions and market factors which are uncertain and subject to change. Changes in the judgments, assumptions and market factors used could result in significantly different estimates of fair value. For perspective, if the discount rate as of June 30, 2022 were to increase or decrease by 100 basis points, the estimated fair value of P&G’s interest would decrease by approximately $75 or increase by approximately $98, respectively. Such changes would affect the amount of future charges to Cost of products sold.
SUMMARY OF NON-GAAP FINANCIAL MEASURES
The non-GAAP financial measures that may be included in this MD&A and Exhibit 99.2 and the reasons management believes they are useful to investors are described below. These measures should be considered supplemental in nature and are not intended to be a substitute for the related financial information prepared in accordance with U.S. GAAP. In addition, these measures may not be the same as similarly named measures presented by other companies.
Free cash flow is calculated as net cash provided by operations less capital expenditures. The Company’s management uses this measure and free cash flow as a percentage of net sales to help assess the cash generation ability of the business and funds available for investing activities, such as acquisitions, investing in the business to drive growth, and financing activities, including debt payments, dividend payments and stock repurchases. Free cash flow does not represent cash available only for discretionary expenditures, since the Company has mandatory debt service requirements and other contractual and non-discretionary expenditures. Refer to “Free cash flow” and “Free cash flow as a percentage of net sales” above for a reconciliation of these non-GAAP measures.
16

EBIT represents earnings before income taxes, interest income and interest expense. EBIT margin is the ratio of EBIT to net sales. The Company’s management believes these measures provide useful additional information to investors to enhance their understanding about trends in the Company’s operations and are useful for period-over-period comparisons.
Economic profit (EP) is defined by the Company as earnings before income taxes, excluding certain U.S. GAAP items (such as asset impairments, charges related to digital capabilities and productivity enhancements investment, significant losses/(gains) related to acquisitions and other non-recurring or unusual items) and interest expense; less income taxes (calculated based on the Company’s effective tax rate excluding the identified U.S. GAAP items), and less after tax profit attributable to noncontrolling interests, and less a capital charge (calculated as average capital employed multiplied by a cost of capital rate). EP is a key financial metric that the Company’s management uses to evaluate business performance and allocate resources, and is a component in determining employee incentive compensation. The Company’s management believes EP provides additional perspective to investors about financial returns generated by the business and represents profit generated over and above the cost of capital used by the business to generate that profit. Refer to Exhibit 99.2 for a reconciliation of EP to earnings before income taxes.
Organic sales growth / (decrease) is defined as net sales growth excluding the effect of foreign exchange rate changes and any acquisitions and divestitures. Management believes that the presentation of organic sales growth / (decrease) is useful to investors because it excludes sales from any acquisitions and divestitures, which results in a comparison of sales only from the businesses that the Company was operating and expects to continue to operate throughout the relevant periods, and the Company’s estimate of the impact of foreign exchange rate changes, which are difficult to predict, and out of the control of the Company and management.
The following table provides a reconciliation of organic sales growth / (decrease) (non-GAAP) to net sales growth / (decrease) (GAAP), the most comparable GAAP measure:

| Twelve Months Ended June 30, 2022
| Percentage change versus the year-ago period
| Health and Wellness | Household | Lifestyle | International | Total
Net sales growth / (decrease) (GAAP) | (10) | % | — | % | 3 | % | 2 | % | (3) | %
Add: Foreign Exchange | — |  | — |  | — |  | 4 |  | 1 |
Add/(Subtract): Divestitures/Acquisitions | — |  | — |  | — |  | — |  | — |
Organic sales growth / (decrease) (non-GAAP) | (10) | % | — | % | 3 | % | 6 | % | (2) | %

17

CAUTIONARY STATEMENT
This Annual Report on Form 10-K (this Report), including the exhibits hereto and the information incorporated by reference herein, contains “forward-looking statements” within the meaning of Section 27A of the Securities Act of 1933, as amended, and Section 21E of the Securities Exchange Act of 1934, as amended, including, among others, statements related to the expected or potential impact of the novel coronavirus (COVID-19) pandemic, and the related responses of governments, consumers, customers, suppliers, employees and the Company, on our business, operations, employees, financial condition and results of operations, and any such forward-looking statements, whether concerning the COVID-19 pandemic or otherwise, involve risks, assumptions and uncertainties. Except for historical information, statements about future volumes, sales, organic sales growth, foreign currencies, costs, cost savings, margins, earnings, earnings per share, diluted earnings per share, foreign currency exchange rates, tax rates, cash flows, plans, objectives, expectations, growth or profitability are forward-looking statements based on management’s estimates, beliefs, assumptions and projections. Words such as “could,” “may,” “expects,” “anticipates,” “targets,” “goals,” “projects,” “intends,” “plans,” “believes,” “seeks,” “estimates,” “will,” “predicts,” and variations on such words, and similar expressions that reflect our current views with respect to future events and operational, economic and financial performance are intended to identify such forward-looking statements. These forward-looking statements are only predictions, subject to risks and uncertainties, and actual results could differ materially from those discussed. Important factors that could affect performance and cause results to differ materially from management’s expectations are described in the sections entitled “Risk Factors” and “Management’s Discussion and Analysis of Financial Condition and Results of Operations” in this Report, as updated from time to time in the Company’s Securities and Exchange Commission filings. These factors include, but are not limited to:
•the impact of the changing retail environment, including the growth of alternative retail channels and business models, and changing consumer preferences;
•volatility and increases in the costs of raw materials, energy, transportation, labor and other necessary supplies or services;
•the ability of the Company to drive sales growth, increase prices and market share, grow its product categories and manage favorable product and geographic mix;
•risks related to supply chain issues, product shortages and disruptions to the business, as a result of increased supply chain dependencies due to an expanded supplier network and a reliance on certain single-source suppliers;
•the ongoing COVID-19 pandemic and related impacts, including on the availability of, and efficiency of the supply, manufacturing and distribution systems for, the Company’s products, including any significant disruption to such systems; on the demand for and sales of the Company’s products; and on worldwide, regional and local adverse economic conditions
•intense competition in the Company’s markets;
•unfavorable general economic and political conditions beyond our control, including recent supply chain disruptions, labor shortages, wage pressures, rising inflation, fuel and energy costs, foreign currency exchange rate fluctuations, weather events or natural disasters, disease outbreaks or pandemics, such as COVID-19, terrorism, and unstable geopolitical conditions, including the conflict in Ukraine;
•risks related to the Company’s use of and reliance on information technology systems, including potential security breaches, cyber-attacks, privacy breaches or data breaches that result in the unauthorized disclosure of consumer, customer, employee or Company information, or service interruptions, especially at a time when a large number of the Company’s employees are working remotely and accessing its technology infrastructure remotely;
•the ability of the Company to implement and generate cost savings and efficiencies, and successfully implement its business strategies, including achieving anticipated results and cost savings from the implementation of the streamlined operating model;
•dependence on key customers and risks related to customer consolidation and ordering patterns;
•the Company’s ability to attract and retain key personnel, which may continue to be impacted by challenges in the labor market, such as wage inflation and sustained labor shortages;
•the Company’s ability to maintain its business reputation and the reputation of its brands and products;
•lower revenue, increased costs or reputational harm resulting from government actions and compliance with regulations, or any material costs imposed by changes in regulation;
18

•the ability of the Company to successfully manage global political, legal, tax and regulatory risks, including changes in regulatory or administrative activity;
•risks related to international operations and international trade, including changing macroeconomic conditions as a result of inflation, volatile commodity prices and increases in raw and packaging materials prices, labor, energy and logistics; global economic or political instability; foreign currency fluctuations, such as devaluations, and foreign currency exchange rate controls; changes in governmental policies, including trade, travel or immigration restrictions, new or additional tariffs, and price or other controls; labor claims and civil unrest; continued high levels of inflation in Argentina; potential disruption from wars and military conflicts, including the conflict in Ukraine; impact of the United Kingdom’s exit from the European Union; potential negative impact and liabilities from the use, storage and transportation of chlorine in certain international markets where chlorine is used in the production of bleach; widespread health emergencies, such as COVID-19; and the possibility of nationalization, expropriation of assets or other government action;
•the impact of Environmental, Social, and Governance (ESG) issues, including those related to climate change and sustainability on our sales, operating costs or reputation;
•the ability of the Company to innovate and to develop and introduce commercially successful products, or expand into adjacent categories and countries;
•the impact of product liability claims, labor claims and other legal, governmental or tax proceedings, including in foreign jurisdictions and in connection with any product recalls;
•risks relating to acquisitions, new ventures and divestitures, and associated costs; and the ability to complete announced transactions and, if completed, integration costs and potential contingent liabilities related to those transactions;
•the accuracy of the Company’s estimates and assumptions on which its financial projections, including any sales or earnings guidance or outlook it may provide from time to time, are based;
•risks related to additional increases in the estimated fair value of P&G’s interest in the Glad business;
•environmental matters, including costs associated with the remediation and monitoring of past contamination, and possible increases in costs resulting from actions by relevant regulators, and the handling and/or transportation of hazardous substances;
•the Company’s ability to effectively utilize, assert and defend its intellectual property rights, and any infringement or claimed infringement by the Company of third-party intellectual property rights;
•the performance of strategic alliances and other business relationships;
•the effect of the Company’s indebtedness and credit rating on its business operations and financial results and the Company’s ability to access capital markets and other funding sources;
•the Company’s ability to pay and declare dividends or repurchase its stock in the future;
•the impacts of potential stockholder activism; and
•risks related to any litigation associated with the exclusive forum provision in the Company’s bylaws.
The Company’s forward-looking statements in this Report are based on management’s current views, beliefs, assumptions and expectations regarding future events and speak only as of the date of this Report. The Company undertakes no obligation to publicly update or revise any forward-looking statements, whether as a result of new information, future events or otherwise, except as required by the federal securities laws. In this Report, unless the context requires otherwise, the terms “the Company,” “Clorox,” “we,” “us,” and “our” refer to The Clorox Company and its subsidiaries.
19

MANAGEMENT’S REPORT ON INTERNAL CONTROL OVER FINANCIAL REPORTING
The Company’s management is responsible for establishing and maintaining adequate internal control over financial reporting. The Company’s internal control over financial reporting is a process designed under the supervision of its Chief Executive Officer and Chief Financial Officer to provide reasonable assurance regarding the reliability of financial reporting and the preparation of the Company’s financial statements for external reporting in accordance with accounting principles generally accepted in the United States of America.
Because of its inherent limitations, internal control over financial reporting may not prevent or detect misstatements. Also, projections of any evaluation of effectiveness to future periods are subject to the risk that controls may become inadequate because of changes in conditions or that the degree of compliance with the policies or procedures may deteriorate.
Management evaluated the effectiveness of the Company’s internal control over financial reporting using the criteria set forth by the Committee of Sponsoring Organizations of the Treadway Commission (COSO) in Internal Control-Integrated Framework published in 2013. Management, under the supervision and with the participation of the Company’s Chief Executive Officer and Chief Financial Officer, assessed the effectiveness of the Company’s internal control over financial reporting as of June 30, 2022, and concluded that it is effective.
The Company’s independent registered public accounting firm, Ernst & Young LLP, has audited the effectiveness of the Company’s internal control over financial reporting as of June 30, 2022, as stated in their report, which is included herein.
20

REPORT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM
To the Stockholders and the Board of Directors of The Clorox Company
Opinion on the Financial Statements
We have audited the accompanying consolidated balance sheets of The Clorox Company (the Company) as of June 30, 2022 and 2021, the related consolidated statements of earnings, comprehensive income, stockholders’ equity and cash flows for each of the three years in the period ended June 30, 2022, and the related notes (collectively referred to as the “consolidated financial statements”). In our opinion, the consolidated financial statements present fairly, in all material respects, the financial position of the Company at June 30, 2022 and 2021, and the results of its operations and its cash flows for each of the three years in the period ended June 30, 2022, in conformity with U.S. generally accepted accounting principles.
We also have audited, in accordance with the standards of the Public Company Accounting Oversight Board (United States) (PCAOB), the Company’s internal control over financial reporting as of June 30, 2022, based on criteria established in Internal Control-Integrated Framework issued by the Committee of Sponsoring Organizations of the Treadway Commission (2013 framework) and our report dated August 10, 2022 expressed an unqualified opinion thereon.
Basis for Opinion
These financial statements are the responsibility of the Company's management. Our responsibility is to express an opinion on the Company’s financial statements based on our audits. We are a public accounting firm registered with the PCAOB and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.
We conducted our audits in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the financial statements are free of material misstatement, whether due to error or fraud. Our audits included performing procedures to assess the risks of material misstatement of the financial statements, whether due to error or fraud, and performing procedures that respond to those risks. Such procedures included examining, on a test basis, evidence regarding the amounts and disclosures in the financial statements. Our audits also included evaluating the accounting principles used and significant estimates made by management, as well as evaluating the overall presentation of the financial statements. We believe that our audits provide a reasonable basis for our opinion.
Critical Audit Matters
The critical audit matters communicated below are matters arising from the current period audit of the financial statements that were communicated or required to be communicated to the audit committee and that: (1) relate to accounts or disclosures that are material to the financial statements and (2) involved our especially challenging, subjective, or complex judgments. The communication of critical audit matters does not alter in any way our opinion on the consolidated financial statements, taken as a whole, and we are not, by communicating the critical audit matters below, providing separate opinions on the critical audit matters or on the accounts or disclosures to which they relate.
21

| Valuation of Goodwill and Trademarks with Indefinite Lives
Description of the Matter | At June 30, 2022, the Company’s goodwill was $1.6 billion and represented 25% of total assets; trademarks with indefinite lives was $668 million and represented 11% of total assets. As discussed in Note 1 of the consolidated financial statements, goodwill and trademarks with indefinite lives are tested by the Company’s management for impairment at least annually, in the fiscal fourth quarter, unless there are indications of impairment at other points throughout the year. Goodwill is tested for impairment at the reporting unit level. Auditing the Company’s annual impairment test for goodwill and trademarks with indefinite lives is complex and highly judgmental and required the involvement of a valuation specialist due to the significant judgment in estimating the fair value of reporting units and trademarks with indefinite lives. In particular, the fair value estimates of reporting units with fair values that do not significantly exceed or that fall below their carrying values are sensitive to assumptions such as net sales growth rates, gross margins and discount rates. Trademarks with indefinite lives with fair values that do not significantly exceed or that fall below their carrying values are sensitive to assumptions such as net sales growth rates, discount rates and royalty rates. All of these assumptions are sensitive to and affected by expected future market or economic conditions, particularly those in emerging markets, and industry and company-specific qualitative factors.

How We Addressed the Matter in Our Audit | We obtained an understanding, evaluated the design and tested the operating effectiveness of controls over the Company’s goodwill and trademarks impairment review process. This included evaluating controls over the Company’s budgetary and forecasting process used to develop the estimated future earnings and cash flows used in estimating the fair value of reporting units and trademarks with indefinite lives. We also tested controls over management’s review of the data used in their valuation models and review of the significant assumptions such as estimation of net sales, expense growth rates and terminal growth rates. To test the estimated fair value of the Company’s reporting units and trademarks with indefinite lives (with fair values that do not significantly exceed or that fall below carrying values), we performed audit procedures that included, among others, assessing the methodologies, testing the significant assumptions discussed above used to develop the estimates of future earnings and cash flows and testing the completeness and accuracy of the underlying data. We compared the significant assumptions used by management to current industry and economic trends, the Company’s historical results and other guideline companies within the same industry, and we evaluated whether changes in the Company’s business would affect the significant assumptions. We assessed the historical accuracy of management’s estimates and performed sensitivity analyses of significant assumptions to evaluate the change in the fair value of the reporting units and trademarks with indefinite lives resulting from changes in these assumptions. We involved our valuation specialists to assist in reviewing the valuation methodology and testing the terminal growth rates, discount rates and royalty rates. In addition, for goodwill we also tested the Company’s calculation of implied multiples of the reporting units, compared them to guideline companies and evaluated the resulting premium. For trademarks with indefinite lives, where applicable, we also assessed whether the assumptions used were consistent with those used in the goodwill impairment review process.

22

| Valuation of Venture Agreement Terminal Obligation
Description of the Matter | As discussed in Note 8 of the consolidated financial statements, the Company has an agreement with The Proctor & Gamble Company (P&G) for the Company’s Glad bags and wraps business, for which the Company is required to purchase P&G’s 20% interest in the venture for cash at fair value of the global Glad business upon termination of the agreement. At June 30, 2021, the fair value of $468 million has been recognized as a venture agreement terminal obligation and represented 9% of total liabilities. Auditing the Company’s Glad venture agreement terminal obligation is complex and highly judgmental and required the involvement of a valuation specialist due to the significant judgment in estimating the fair value of the global Glad business. In particular, the fair value estimate is sensitive to assumptions such as net sales growth rates, gross margins, discount rate and commodity prices. These assumptions are sensitive to and affected by expected future market or economic conditions, particularly those in emerging markets, and industry and company-specific qualitative factors.
How We Addressed the Matter in Our Audit | We obtained an understanding, evaluated the design and tested the operating effectiveness of controls over the venture agreement terminal obligation valuation review process. This included controls over the Company’s budgetary and forecasting process used to develop the estimated fair value of the global Glad business. We also tested management’s controls over the data used in their valuation models and review of the significant assumptions such as estimation of net sales, expense growth rates, terminal growth rates and commodity prices. To test the estimated fair value of the venture agreement terminal obligation, we performed audit procedures that included, among others, assessing the methodologies, testing the significant assumptions discussed above used to develop estimates of future earnings and cash flows, and testing the completeness and accuracy of the underlying data. We compared the significant assumptions used by management to current industry and economic trends, the Company’s historical results and other guideline companies within the same industry, and we evaluated whether changes in the Company’s business, including shifts in consumer demands and commodity prices, would affect the significant assumptions. We assessed the historical accuracy of management’s estimates and performed sensitivity analyses of significant assumptions to evaluate the change in the fair value of the venture agreement terminal obligation resulting from changes in these assumptions. We involved our valuation specialists to assist in reviewing the valuation methodology and testing the terminal growth rates and discount rates.

/s/ Ernst & Young LLP
We have served as the Company’s auditor since 2003.
San Francisco, CA
August 10, 2022
23

REPORT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM
To the Stockholders and the Board of Directors of The Clorox Company
Opinion on Internal Control Over Financial Reporting
We have audited The Clorox Company’s internal control over financial reporting as of June 30, 2022, based on criteria established in Internal Control - Integrated Framework issued by the Committee of Sponsoring Organizations of the Treadway Commission (2013 framework) (the COSO criteria). In our opinion, The Clorox Company (the Company) maintained, in all material respects, effective internal control over financial reporting as of June 30, 2022, based on the COSO criteria.
We also have audited, in accordance with the standards of the Public Company Accounting Oversight Board (United States) (PCAOB), the consolidated balance sheets of The Clorox Company as of June 30, 2022 and 2021, the related consolidated statements of earnings, comprehensive income, stockholders’ equity and cash flows for each of the three years in the period ended June 30, 2022, and the related notes (collectively referred to as the “consolidated financial statements”) and our report dated August 10, 2022 expressed an unqualified opinion thereon.
Basis for Opinion
The Company’s management is responsible for maintaining effective internal control over financial reporting and for its assessment of the effectiveness of internal control over financial reporting included in the accompanying Management’s Report on Internal Control Over Financial Reporting. Our responsibility is to express an opinion on the Company’s internal control over financial reporting based on our audit. We are a public accounting firm registered with the PCAOB and are required to be independent with respect to the Company in accordance with the U.S. federal securities laws and the applicable rules and regulations of the Securities and Exchange Commission and the PCAOB.
We conducted our audit in accordance with the standards of the PCAOB. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether effective internal control over financial reporting was maintained in all material respects.
Our audit included obtaining an understanding of internal control over financial reporting, assessing the risk that a material weakness exists, testing and evaluating the design and operating effectiveness of internal control based on the assessed risk, and performing such other procedures as we considered necessary in the circumstances. We believe that our audit provides a reasonable basis for our opinion.
Definition and Limitations of Internal Control Over Financial Reporting
A company’s internal control over financial reporting is a process designed to provide reasonable assurance regarding the reliability of financial reporting and the preparation of financial statements for external purposes in accordance with generally accepted accounting principles. A company’s internal control over financial reporting includes those policies and procedures that (1) pertain to the maintenance of records that, in reasonable detail, accurately and fairly reflect the transactions and dispositions of the assets of the company; (2) provide reasonable assurance that transactions are recorded as necessary to permit preparation of financial statements in accordance with generally accepted accounting principles, and that receipts and expenditures of the company are being made only in accordance with authorizations of management and directors of the company; and (3) provide reasonable assurance regarding prevention or timely detection of unauthorized acquisition, use, or disposition of the company’s assets that could have a material effect on the financial statements.
Because of its inherent limitations, internal control over financial reporting may not prevent or detect misstatements. Also, projections of any evaluation of effectiveness to future periods are subject to the risk that controls may become inadequate because of changes in conditions, or that the degree of compliance with the policies or procedures may deteriorate.
/s/ Ernst & Young LLP
San Francisco, CA
August 10, 2022
24

CONSOLIDATED STATEMENTS OF EARNINGS
The Clorox Company
Years ended June 30

Dollars in millions, except per share data |  | 2022 |  | 2021 |  | 2020
Net sales |  | $ | 7,107 |  |  | $ | 7,341 |  |  | $ | 6,721 |
Cost of products sold |  | 4,562 |  |  | 4,142 |  |  | 3,658 |
Gross profit |  | 2,545 |  |  | 3,199 |  |  | 3,063 |
Selling and administrative expenses |  | 954 |  |  | 1,004 |  |  | 969 |
Advertising costs |  | 709 |  |  | 790 |  |  | 675 |
Research and development costs |  | 132 |  |  | 149 |  |  | 145 |
Goodwill, trademark and other asset impairments |  | — |  |  | 329 |  |  | — |
Interest expense |  | 106 |  |  | 99 |  |  | 99 |
Other (income) expense, net |  | 37 |  |  | (72) |  |  | (10) |
Earnings before income taxes |  | 607 |  |  | 900 |  |  | 1,185 |
Income taxes |  | 136 |  |  | 181 |  |  | 246 |
Net earnings |  | 471 |  |  | 719 |  |  | 939 |
Less: Net earnings attributable to noncontrolling interests |  | 9 |  |  | 9 |  |  | — |
Net earnings attributable to Clorox |  | $ | 462 |  |  | $ | 710 |  |  | $ | 939 |
Net earnings per share attributable to Clorox |  |  |  |  |  |
Basic net earnings per share |  | $ | 3.75 |  |  | $ | 5.66 |  |  | $ | 7.46 |
Diluted net earnings per share |  | $ | 3.73 |  |  | $ | 5.58 |  |  | $ | 7.36 |
Weighted average shares outstanding (in thousands) |  |  |  |  |  |
Basic |  | 123,113 |  |  | 125,570 |  |  | 125,828 |
Diluted |  | 123,906 |  |  | 127,299 |  |  | 127,671 |

See Notes to Consolidated Financial Statements
25

CONSOLIDATED STATEMENTS OF COMPREHENSIVE INCOME
The Clorox Company

Years ended June 30 |  |  |  |  |  |
Dollars in millions |  | 2022 |  | 2021 |  | 2020
Net earnings |  | $ | 471 |  |  | $ | 719 |  |  | $ | 939 |
Other comprehensive (loss) income: |  |  |  |  |  |
Foreign currency adjustments, net of tax |  | (45) |  |  | 47 |  |  | (36) |
Net unrealized gains (losses) on derivatives, net of tax |  | 100 |  |  | 39 |  |  | 5 |
Pension and postretirement benefit adjustments, net of tax |  | 12 |  |  | 8 |  |  | (7) |
Total other comprehensive (loss) income, net of tax |  | 67 |  |  | 94 |  |  | (38) |
Comprehensive income |  | 538 |  |  | 813 |  |  | 901 |
Less: Total comprehensive income attributable to noncontrolling interests |  | 9 |  |  | 9 |  |  | — |
Total comprehensive income attributable to Clorox |  | $ | 529 |  |  | $ | 804 |  |  | $ | 901 |

See Notes to Consolidated Financial Statements
26

CONSOLIDATED BALANCE SHEETS
The Clorox Company

As of June 30 |  |  |  |
Dollars in millions, except per share data |  | 2022 |  | 2021
ASSETS |  |  |  |
Current assets |  |  |  |
Cash and cash equivalents |  | $ | 183 |  |  | $ | 319 |
Receivables, net |  | 681 |  |  | 604 |
Inventories, net |  | 755 |  |  | 752 |
Prepaid expenses and other current assets |  | 106 |  |  | 154 |
Total current assets |  | 1,725 |  |  | 1,829 |
Property, plant and equipment, net |  | 1,334 |  |  | 1,302 |
Operating lease right-of-use assets |  | 342 |  |  | 332 |
Goodwill |  | 1,558 |  |  | 1,575 |
Trademarks, net |  | 687 |  |  | 693 |
Other intangible assets, net |  | 197 |  |  | 225 |
Other assets |  | 315 |  |  | 378 |
Total assets |  | $ | 6,158 |  |  | $ | 6,334 |
LIABILITIES AND STOCKHOLDERS’ EQUITY |  |  |  |
Current liabilities |  |  |  |
Notes and loans payable |  | $ | 237 |  |  | $ | — |
Current maturities of long-term debt |  | — |  |  | 300 |
Current operating lease liabilities |  | 78 |  |  | 81 |
Accounts payable and accrued liabilities |  | 1,469 |  |  | 1,675 |
Total current liabilities |  | 1,784 |  |  | 2,056 |
Long-term debt |  | 2,474 |  |  | 2,484 |
Long-term operating lease liabilities |  | 314 |  |  | 301 |
Other liabilities |  | 791 |  |  | 834 |
Deferred income taxes |  | 66 |  |  | 67 |
Total liabilities |  | 5,429 |  |  | 5,742 |
Commitments and contingencies |  |  |  |
Stockholders’ equity |  |  |  |
Preferred stock: $1.00 par value; 5,000,000 shares authorized; none issued or outstanding |  | — |  |  | — |
Common stock: $1.00 par value; 750,000,000 shares authorized; 130,741,461 shares issued as of June 30, 2022 and 2021; and 123,152,132 and 122,780,220 shares outstanding as of June 30, 2022 and 2021, respectively |  | 131 |  |  | 131 |
Additional paid-in capital |  | 1,202 |  |  | 1,186 |
Retained earnings |  | 1,048 |  |  | 1,036 |
Treasury stock, at cost: 7,589,329 and 7,961,241 shares as of June 30, 2022 and 2021, respectively |  | (1,346) |  |  | (1,396) |
Accumulated other comprehensive net (loss) income |  | (479) |  |  | (546) |
Total Clorox stockholders’ equity |  | 556 |  |  | 411 |
Noncontrolling interests |  | 173 |  |  | 181 |
Total stockholders’ equity |  | 729 |  |  | 592 |
Total liabilities and stockholders’ equity |  | $ | 6,158 |  |  | $ | 6,334 |

See Notes to Consolidated Financial Statements
27

CONSOLIDATED STATEMENTS OF STOCKHOLDERS’ EQUITY
The Clorox Company

|  | Common Stock | Additional Paid-in Capital |  |  |  | Treasury Stock | Accumulated Other Comprehensive Net (Loss) Income |  | Non-controlling interests |  | Total Stockholders’ Equity
(Dollars in millions except per share data; shares in thousands) |  | Amount |  | Shares |  | Retained Earnings |  | Amount |  | Shares |  |
Balance as of June 30, 2019 |  | $ | 159 |  |  | 158,741 |  |  | $ | 1,046 |  |  | $ | 3,150 |  |  | $ | (3,194) |  |  | (33,055) |  |  | $ | (602) |  |  | $ | — |  |  | $ | 559 |
Cumulative effect of accounting changes (1) |  | — |  |  | — |  |  | — |  |  | 22 |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 22 |
Net earnings |  | — |  |  | — |  |  | — |  |  | 939 |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 939 |
Other comprehensive (loss) income |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | (38) |  |  | — |  |  | (38) |
Dividends to Clorox stockholders ($4.29 per share declared) |  | — |  |  | — |  |  | — |  |  | (544) |  |  | — |  |  | — |  |  | — |  |  | — |  |  | (544) |
Stock-based compensation |  | — |  |  | — |  |  | 50 |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 50 |
Other employee stock plan activities |  | — |  |  | — |  |  | 41 |  |  | — |  |  | 121 |  |  | 2,043 |  |  | — |  |  | — |  |  | 162 |
Treasury stock purchased |  | — |  |  | — |  |  | — |  |  | — |  |  | (242) |  |  | (1,531) |  |  | — |  |  | — |  |  | (242) |
Balance as of June 30, 2020 |  | 159 |  |  | 158,741 |  |  | 1,137 |  |  | 3,567 |  |  | (3,315) |  |  | (32,543) |  |  | (640) |  |  | — |  |  | 908 |
Net earnings |  | — |  |  | — |  |  | — |  |  | 710 |  |  | — |  |  | — |  |  | — |  |  | 9 |  |  | 719 |
Other comprehensive (loss) income |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 94 |  |  | — |  |  | 94 |
Dividends to Clorox stockholders ($4.49 per share declared) |  | — |  |  | — |  |  | — |  |  | (564) |  |  | — |  |  | — |  |  | — |  |  | — |  |  | (564) |
Dividends to noncontrolling interests |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | (26) |  |  | (26) |
Business combinations including purchase accounting adjustments |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 198 |  |  | 198 |
Stock-based compensation |  | — |  |  | — |  |  | 50 |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 50 |
Other employee stock plan activities |  | — |  |  | — |  |  | (1) |  |  | (37) |  |  | 156 |  |  | 1,340 |  |  | — |  |  | — |  |  | 118 |
Treasury stock purchased |  |  |  |  |  | — |  |  |  |  | (905) |  |  | (4,758) |  |  | — |  |  | — |  |  | (905) |
Treasury stock retirement |  | (28) |  |  | (28,000) |  |  |  |  | (2,640) |  |  | 2,668 |  |  | 28,000 |  |  | — |  |  | — |  |  | — |
Balance as of June 30, 2021 |  | 131 |  |  | 130,741 |  |  | 1,186 |  |  | 1,036 |  |  | (1,396) |  |  | (7,961) |  |  | (546) |  |  | 181 |  |  | 592 |
Net earnings |  | — |  |  | — |  |  | — |  |  | 462 |  |  | — |  |  | — |  |  | — |  |  | 9 |  |  | 471 |
Other comprehensive (loss) income |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 67 |  |  | — |  |  | 67 |
Dividends to Clorox stockholders ($3.48 per share declared) |  | — |  |  | — |  |  | — |  |  | (430) |  |  | — |  |  | — |  |  | — |  |  | — |  |  | (430) |
Dividends to noncontrolling interests |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | (17) |  |  | (17) |
Stock-based compensation |  | — |  |  | — |  |  | 52 |  |  | — |  |  | — |  |  | — |  |  | — |  |  | — |  |  | 52 |
Other employee stock plan activities |  | — |  |  | — |  |  | (36) |  |  | (20) |  |  | 75 |  |  | 524 |  |  | — |  |  | — |  |  | 19 |
Treasury stock purchased |  | — |  |  | — |  |  | — |  |  | — |  |  | (25) |  |  | (152) |  |  | — |  |  | — |  |  | (25) |
Balance as of June 30, 2022 |  | $ | 131 |  |  | 130,741 |  |  | $ | 1,202 |  |  | $ | 1,048 |  |  | $ | (1,346) |  |  | (7,589) |  |  | $ | (479) |  |  | $ | 173 |  |  | $ | 729 |

(1) As a result of adopting ASU No. 2016-02, “Leases (ASC 842),” on July 1, 2019, the Company recorded a cumulative effect of initially applying the new
guidance as an adjustment to the fiscal year 2020 opening balance of Retained earnings.
See Notes to Consolidated Financial Statements
28

CONSOLIDATED STATEMENTS OF CASH FLOWS
The Clorox Company

Years ended June 30 |  |  |  |  |  |
Dollars in millions |  | 2022 |  | 2021 |  | 2020
Operating activities: |  |  |  |  |  |
Net earnings |  | $ | 471 |  |  | $ | 719 |  |  | $ | 939 |
Adjustments to reconcile net earnings to net cash provided by operations: |  |  |  |  |  |
Depreciation and amortization |  | 224 |  |  | 211 |  |  | 180 |
Stock-based compensation |  | 52 |  |  | 50 |  |  | 50 |
Deferred income taxes |  | 5 |  |  | (32) |  |  | (2) |
Goodwill, trademark and other asset impairments |  | — |  |  | 329 |  |  | — |
Settlement of interest rate derivative contracts |  | 114 |  |  | — |  |  | — |
Other |  | 19 |  |  | 10 |  |  | 30 |
Changes in: |  |  |  |  |  |
Receivables, net |  | (84) |  |  | 82 |  |  | (27) |
Inventories, net |  | (18) |  |  | (282) |  |  | 50 |
Prepaid expenses and other current assets |  | 16 |  |  | (30) |  |  | 2 |
Accounts payable and accrued liabilities |  | (47) |  |  | 311 |  |  | 291 |
Operating lease right-of-use assets and liabilities, net |  | (1) |  |  | (2) |  |  | 19 |
Income taxes payable/prepaid |  | 35 |  |  | (90) |  |  | 14 |
Net cash provided by operations |  | 786 |  |  | 1,276 |  |  | 1,546 |
Investing activities: |  |  |  |  |  |
Capital expenditures |  | (251) |  |  | (331) |  |  | (254) |
Businesses acquired, net of cash acquired |  | — |  |  | (85) |  |  | — |
Other |  | 22 |  |  | (36) |  |  | 2 |
Net cash used for investing activities |  | (229) |  |  | (452) |  |  | (252) |
Financing activities: |  |  |  |  |  |
Notes and loans payable, net |  | 237 |  |  | — |  |  | (396) |
Long-term debt repayments |  | (1,405) |  |  | — |  |  | — |
Long-term debt borrowings, net of issuance costs paid |  | 1,085 |  |  | — |  |  | 492 |
Treasury stock purchased |  | (25) |  |  | (905) |  |  | (248) |
Cash dividends paid to Clorox stockholders |  | (571) |  |  | (558) |  |  | (533) |
Cash dividends paid to noncontrolling interests |  | (15) |  |  | (31) |  |  | — |
Issuance of common stock for employee stock plans and other |  | 5 |  |  | 103 |  |  | 162 |
Net cash used for financing activities |  | (689) |  |  | (1,391) |  |  | (523) |
Effect of exchange rate changes on cash, cash equivalents and restricted cash |  | (6) |  |  | 12 |  |  | (5) |
Net increase (decrease) in cash, cash equivalents and restricted cash |  | (138) |  |  | (555) |  |  | 766 |
Cash, cash equivalents and restricted cash: |  |  |  |  |  |
Beginning of year |  | 324 |  |  | 879 |  |  | 113 |
End of year |  | $ | 186 |  |  | $ | 324 |  |  | $ | 879 |
Supplemental cash flow information: |  |  |  |  |  |
Interest paid |  | $ | 89 |  |  | $ | 89 |  |  | $ | 89 |
Income taxes paid, net of refunds |  | 100 |  |  | 303 |  |  | 241 |
Non-cash financing activities: |  |  |  |  |  |
Cash dividends declared and accrued, but not paid |  | 14 |  |  | 156 |  |  | 140 |

See Notes to Consolidated Financial Statements
29

NOTES TO CONSOLIDATED FINANCIAL STATEMENTS
The Clorox Company
(Dollars in millions, except per share data)
NOTE 1. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES
Nature of Operations and Basis of Presentation
The Company is principally engaged in the production, marketing and sale of consumer products through mass retailers, grocery outlets, warehouse clubs, dollar stores, home hardware centers, drug, pet and military stores, third-party and owned e-commerce channels, and distributors. The consolidated financial statements include the statements of the Company and its wholly owned and controlled subsidiaries. All significant intercompany transactions and accounts were eliminated in consolidation.
Use of Estimates
The preparation of these consolidated financial statements in conformity with generally accepted accounting principles in the United States of America (U.S. GAAP) requires management to reach opinions as to estimates and assumptions that affect reported amounts and related disclosures. Specific areas requiring the application of management’s estimates and judgments include, among others, assumptions pertaining to accruals for consumer and trade-promotion programs, stock-based compensation, retirement income plans, future cash flows associated with impairment testing of goodwill and other long-lived assets and the valuation of the venture agreement terminal obligation, the valuation of assets acquired and liabilities assumed in connection with a business combination, the credit worthiness of customers, uncertain tax positions, tax valuation allowances and legal, environmental and insurance matters. Actual results could materially differ from estimates and assumptions made.
Cash, Cash Equivalents and Restricted Cash
Cash equivalents consist of highly liquid interest-bearing accounts, time deposits held by financial institutions and money market funds with an initial maturity at purchase of 90 days or less. The fair value of cash and cash equivalents approximates the carrying amount.
The Company’s cash position includes amounts held by foreign subsidiaries and, as a result, the repatriation of certain cash balances from some of the Company’s foreign subsidiaries could result in additional withholding tax costs in certain foreign jurisdictions. However, these cash balances are generally available without legal restriction to fund local business operations. In addition, a portion of the Company’s cash balance is held in U.S. dollars by foreign subsidiaries whose functional currency is their local currency. Such U.S. dollar balances are reported on the foreign subsidiaries’ books in their functional currency, and the impact on such balances from foreign currency exchange rate differences is recorded in Other (income) expense, net.
As of June 30, 2022, 2021, 2020 and 2019, the Company had $3, $5, $8 and $2 of restricted cash, respectively, which was included in Prepaid expenses and other current assets and Other assets. The restricted cash as of June 30, 2022 was primarily related to cash margin deposits held for exchange-traded futures contracts and funds held in an escrow account with limitations on usage.
Inventories
The Company values its inventories using both the First-In, First-Out (FIFO) and the Last-In, First-Out (LIFO) methods. The FIFO inventory is stated at the lower of cost or net realizable value, which includes any costs to sell or dispose. In addition, appropriate consideration is given to obsolescence, excessive inventory levels, product deterioration and other factors in evaluating net realizable value. The LIFO inventory is stated at the lower of cost or market.
30

NOTE 1. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)
Property, Plant and Equipment and Finite-Lived Intangible Assets
Property, plant and equipment and finite-lived intangible assets are stated at cost. Depreciation and amortization expense are primarily calculated by the straight-line method using the estimated useful lives or lives determined by reference to the related lease contract in the case of leasehold improvements. The table below provides estimated useful lives of property, plant and equipment by asset classification.

| Estimated Useful Lives
Buildings and leasehold improvements | 7 - 40 years
Land improvements | 10 - 30 years
Machinery and equipment | 3 - 15 years
Computer equipment | 3 - 5 years
Capitalized software costs | 3 - 7 years

Finite-lived intangible assets are amortized over their estimated useful lives, which range from 7 to 30 years.
Property, plant and equipment and finite-lived intangible assets are reviewed for impairment whenever events or changes in circumstances occur that indicate that the carrying amount of an asset (or asset group) may not be fully recoverable. The risk of impairment is initially assessed based on an estimate of the undiscounted cash flows at the lowest level for which identifiable cash flows exist. Impairment occurs when the carrying value of the asset (or asset group) exceeds the estimated future undiscounted cash flows generated by the asset (or asset group). When impairment is indicated, an impairment charge is recorded for the difference between the carrying value of the asset (or asset group) and its estimated fair market value. Depending on the asset, estimated fair market value may be determined either by use of a discounted cash flow model or by reference to estimated selling values of assets in similar condition.
Capitalization of Software Costs
The Company capitalizes certain qualifying costs incurred in the acquisition and development of software for internal use, including the costs of the software, materials, consultants, interest and payroll and payroll-related costs for employees during the application development stage. Internal and external costs incurred during the preliminary project stage and post implementation-operation stage, mainly training and maintenance costs, are expensed as incurred. Once the application is substantially complete and ready for its intended use, qualifying costs are amortized on a straight-line basis over the software’s estimated useful life. Capitalized internal use software is included in Property, plant and equipment. Capitalized software as a service is included in Prepaid expenses and other current assets or Other assets and is amortized using the straight-line method over the term of the hosting arrangement which is typically no greater than 6 years.
Business Combinations
The Company records acquired businesses within the consolidated financial statements using the acquisition method prospectively from the acquisition date. Under the acquisition method, once control is obtained, assets acquired and liabilities assumed, including amounts attributable to noncontrolling interests, are recorded at their respective fair values on the acquisition date. The Company’s estimates of fair value are inherently uncertain and subject to refinement. The excess of the total of the purchase consideration, fair value of the noncontrolling interest and fair value of the previously held equity interest over the identifiable assets acquired and liabilities assumed is recorded as goodwill. Measurement period adjustments to the fair values of the identifiable assets acquired and liabilities assumed with the corresponding offset to goodwill, if applicable, are applied in the reporting period in which the adjustment amounts are determined based on new information obtained during the measurement period. In the event of a step acquisition, the Company records a gain or loss in Other income (expense), net on the consolidated statement of earnings as a result of remeasuring a previously held equity interest to fair value on the acquisition date. Transaction expenses are recognized separately from the business combination and are expensed as incurred.
Impairment Review of Goodwill and Indefinite-Lived Intangible Assets
The Company tests its goodwill, trademarks with indefinite lives and other indefinite-lived intangible assets annually for impairment in the fiscal fourth quarter unless there are indications during a different interim period that these assets may have become impaired.
With respect to goodwill, the Company has the option to first assess qualitative factors, such as the maturity and stability of the reporting unit, the magnitude of the excess fair value over carrying value from a previous period’s impairment testing, other reporting unit specific operating results, micro and macroeconomic factors, as well as new events and circumstances impacting the operations at the reporting unit level. Reporting units for goodwill impairment testing purposes were its individual strategic business units (SBUs). If the result of a qualitative test indicates a potential for impairment of a reporting unit, a quantitative
31

NOTE 1. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)
test is performed. In the quantitative test, the Company compares the estimated fair value of the reporting unit to its carrying value. If the estimated fair value of any reporting unit is less than its carrying value, an impairment charge is recorded for the difference between the carrying value and the fair value of the reporting unit.
To determine the fair value of a reporting unit as part of its quantitative test, the Company uses the discounted cash flow (DCF) method under the income approach, as it believes that this approach is the most reliable indicator of the fair value of its businesses and the fair value of their future earnings and cash flows. Under this approach, which requires significant judgments, the Company estimates the future cash flows of each reporting unit and discounts these cash flows at a rate of return that reflects their relative risk. The cash flows used in the DCF method are consistent with those the Company uses in its internal planning, which gives consideration to actual business trends experienced, and the broader business strategy for the long term. The other key estimates and factors used in the DCF method include, but are not limited to, net sales and expense growth rates, commodity prices, foreign exchange rates, inflation and a terminal growth rate. Changes in such estimates or the application of alternative assumptions could produce different results.
For trademarks and other intangible assets with indefinite lives, the Company has the option to first assess qualitative factors, such as the maturity and stability of the trademark or other intangible asset, the magnitude of the excess fair value over carrying value from a previous period’s impairment testing, other specific operating results, as well as new events and circumstances impacting the significant inputs used to determine the fair value of the intangible asset. If the result of a qualitative test indicates that it is more likely than not that the asset is impaired, a quantitative test is performed. When a quantitative test is performed, the estimated fair value of an asset is compared to its carrying value. If the carrying value of such asset exceeds its estimated fair value, an impairment charge is recorded for the difference between the carrying value and the estimated fair value. The Company uses the DCF method under the relief from royalty income approach to estimate the fair value of its trademarks and other intangible assets with indefinite lives. This approach requires significant judgments in determining the royalty rates and the assets’ estimated cash flows, as well as the appropriate discount and foreign exchange rates applied to those cash flows to determine fair value. Changes in such estimates or the use of alternative assumptions could produce different results.
Leases
The Company determines whether an arrangement contains a lease at inception by determining if the contract conveys the right to control the use of identified property, plant or equipment for a period of time in exchange for consideration and other facts and circumstances. Right-of-use (ROU) assets represent the Company’s right to use an underlying asset for the lease term and lease liabilities represent the Company’s obligation to make lease payments arising from the lease. ROU assets are calculated based on the lease liability adjusted for any lease payments paid to the lessor at or before the commencement date and initial direct costs incurred by the Company and excludes any lease incentives received from the lessor. Lease liabilities are recognized based on the present value of the future minimum lease payments over the lease term. The lease term may include an option to extend or terminate the lease when it is reasonably certain that the Company will exercise that option as of the commencement date of the lease, and is reviewed in subsequent periods if a triggering event occurs. As the Company’s leases typically do not contain a readily determinable implicit rate, the Company determines the present value of the lease liability using its incremental borrowing rate at the lease commencement date based on the lease term and the currency of the lease on a collateralized basis. Variable lease payments are the portion of lease payments that are not fixed over the lease term. Variable lease payments are expensed as incurred, and include certain non-lease components, such as maintenance and other services provided by the lessor, and other charges included in the lease, as applicable. The Company elected to combine lease and non-lease components as a single lease component and to exclude short-term leases, defined as leases with an initial term of 12 months or less, from its consolidated balance sheet.
Stock-based Compensation
The Company grants various nonqualified stock-based compensation awards to eligible employees, including stock options, restricted stock awards and performance shares.
For stock options, the Company estimates the fair value of each award on the date of grant using the Black-Scholes valuation model, which requires management to make estimates regarding expected option life, stock price volatility and other assumptions. Groups of employees that have similar historical exercise behavior are considered separately for valuation purposes. The Company estimates stock option forfeitures based on historical data for each employee grouping. The total number of stock options expected to vest is adjusted by actual and estimated forfeitures. Changes to the actual and estimated forfeitures will result in a cumulative adjustment in the period of change. Compensation expense is recorded by amortizing the grant date fair values on a straight-line basis over the vesting period, adjusted for estimated forfeitures.
For restricted stock awards, the fair value of each grant issued is estimated on the date of grant based on the current market price of the stock. Forfeitures are estimated based on historical data. The total number of restricted stock awards expected to vest is adjusted by actual and estimated forfeitures. Changes to the actual and estimated forfeitures will result in a cumulative
32

NOTE 1. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)
adjustment in the period of change. Compensation expense is recorded by amortizing the grant date fair values on a straight-line basis over the vesting period, adjusted for estimated forfeitures.
The Company’s performance shares provide for the issuance of common stock to certain managerial staff and executive management if the Company achieves specified performance targets. The number of shares issued is dependent upon the achievement of specified performance targets. The performance period is three years and the payout determination is made at the end of the three-year performance period. Performance shares receive dividends earned during the vesting period upon vesting. The fair value of each grant issued is estimated on the date of grant based on the current market price of the stock. The total amount of compensation expense recognized reflects estimated forfeiture rates and management’s assessment of the probability that performance goals will be achieved. A cumulative adjustment is recognized to compensation expense in the current period to reflect any changes in the probability of achievement of performance goals.
Cash flows resulting from tax deductions in excess of the cumulative compensation cost recognized for stock-based payment arrangements (excess tax benefits) are classified as operating cash inflows.
Employee Benefits
The Company accounts for its retirement income and retirement health care plans using actuarial methods. These methods use an attribution approach that generally spreads “plan events” over the service lives or expected lifetime (for frozen plans) of plan participants. Examples of plan events are plan amendments and changes in actuarial assumptions such as the expected return on plan assets, discount rate, rate of compensation increase and certain employee-related factors, such as retirement age and mortality. The principle underlying the attribution approach is that employees render service over their employment period on a relatively “smooth” basis and, therefore, the statement of earnings effects of retirement income and retirement health care plans are recognized in the same pattern. One of the principal assumptions used in the net periodic benefit cost calculation is the expected return on plan assets. The expected return on plan assets may result in recognized expense or income that differs from the actual returns of those plan assets in any given year. Over time, however, the goal is for the expected long-term returns to approximate the actual returns and, therefore, the expectation is that the pattern of income and expense recognition should closely match the pattern of the services provided by the participants. The Company uses a market-related value method for calculating plan assets for purposes of determining the amortization of actuarial gains and losses. The differences between actual and expected returns are recognized in the net periodic benefit cost calculation over the average remaining service period or expected lifetime (for frozen plans) of the plan participants using the corridor approach. Under this approach, only actuarial gains (losses) that exceed 5% of the greater of the projected benefit obligation or the market-related value of assets are amortized to the Company’s net periodic benefit cost. In developing its expected return on plan assets, the Company considers the long-term actual returns relative to the mix of investments that comprise its plan assets and also develops estimates of future investment returns by considering external sources.
The Company recognizes an actuarial-based obligation at the onset of disability for certain benefits provided to individuals after employment, but before retirement, that includes medical, dental, vision, life and other benefits.
Environmental Costs
The Company is involved in certain environmental remediation and ongoing compliance activities. Accruals for environmental matters are recorded on a site-by-site basis when it is probable that a liability has been incurred and based upon a reasonable estimate of the liability. The Company’s accruals reflect the anticipated participation of other potentially responsible parties in those instances where it is probable that such parties are legally responsible and financially capable of paying their respective shares of the relevant costs. These accruals are adjusted periodically as assessment and remediation efforts progress or as additional technical or legal information becomes available. Actual costs to be incurred at identified sites in future periods may vary from the estimates, given the inherent uncertainties in evaluating environmental exposures. The accrual for environmental matters is included in Accounts payable and accrued liabilities and Other liabilities in the Company’s consolidated balance sheets on an undiscounted basis due to uncertainty regarding the timing of future payments.
Revenue Recognition
The Company’s revenue is primarily generated from the sale of finished product to customers. Revenue is recognized at the point in time when performance obligations under the terms of customer contracts are satisfied, which is when ownership, risks and rewards transfer, and can be on the date of shipment or the date of receipt by the customer, depending upon the particular customer arrangement. Shipping and handling activities are accounted for as contract fulfillment costs and included within Cost of products sold. After the completion of the performance obligation, there is an unconditional right to consideration as outlined in the contract. A right is considered unconditional if nothing other than the passage of time is required before payment of that consideration is due. The Company typically collects its customer receivables within two months. All performance obligations under the terms of contracts with customers have an original duration of one year or less.
33

NOTE 1. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)
The Company has trade promotion programs, which primarily include shelf price reductions, in-store merchandising and consumer coupons. The costs of such activities, defined as variable consideration under ASC 606, “Revenue from Contracts with Customers,” are netted against sales and recorded when the related sales take place. Accruals for trade promotion programs are established based on the Company’s best estimate of the amounts necessary to settle existing and future obligations for products sold as of the balance sheet date. Amounts accrued for trade-promotions are based on various factors such as contractual terms and sales volumes, and also incorporate estimates that include customer participation rates, the rate at which customers will achieve program performance criteria, product availability and historical consumer redemption rates.
The Company provides an allowance for doubtful accounts based on its historical experience and ongoing assessment of its customers’ credit risk and aging. Customer receivables are presented net of an allowance for doubtful accounts of $9 and $8 as of June 30, 2022 and 2021, respectively. Receivables, net, include non-customer receivables of $22 and $22 as of June 30, 2022 and 2021, respectively, and related allowance of $0 and $14 as of June 30, 2022 and 2021, respectively.
Cost of Products Sold
Cost of products sold represents the costs directly related to the manufacture and distribution of the Company’s products and primarily includes raw materials, packaging, contract manufacturing fees, shipping and handling, warehousing, package design, depreciation, amortization, direct and indirect labor and operating costs for the Company’s manufacturing and distribution facilities, including salary, benefit costs and incentive compensation, and royalties and other charges related to the Company’s Glad Venture Agreement (See Note 8).
Costs associated with developing and designing new packaging, including design, artwork, films and labeling, are expensed as incurred and included within Cost of products sold.
Selling and Administrative Expenses
Selling and administrative expenses represent costs incurred by the Company in generating revenues and managing the business and include market research, commissions and certain administrative expenses. Administrative expenses include salary, benefits, incentive compensation, professional fees and services and other operating costs (such as software and licensing costs) associated with the Company’s non-manufacturing, non-research and development operations.
Advertising and Research and Development Costs
The Company expenses advertising and research and development costs in the period incurred.
Income Taxes
The Company uses the asset and liability method to account for income taxes. Deferred tax assets and liabilities are recognized for the anticipated future tax consequences attributable to differences between financial statement amounts and their respective tax basis. Management reviews the Company’s deferred tax assets to determine whether their value can be realized based upon available evidence. A valuation allowance is established when management believes that it is more likely than not that some portion of its deferred tax assets will not be realized. Changes in valuation allowances from period to period are included in the Company’s income tax provision in the period of change. In addition to valuation allowances, the Company provides for uncertain tax positions when such tax positions do not meet certain recognition thresholds or measurement standards. Amounts for uncertain tax positions are adjusted in quarters when new information becomes available or when positions are effectively settled.
Per U.S. GAAP, foreign withholding taxes are provided on unremitted foreign earnings that are not indefinitely reinvested at the time the earnings are generated. The Company regularly reviews and assesses whether there are any changes to its indefinite reinvestment assertion and determined that none of the undistributed earnings of its foreign subsidiaries are indefinitely reinvested. As a result, the Company is providing foreign withholding taxes on the undistributed earnings of all foreign subsidiaries where applicable.
Foreign Currency Transactions and Translation
Local currencies are the functional currencies for substantially all of the Company’s foreign operations. When the transactional currency is different than the functional currency, transaction gains and losses are included as a component of Other (income) expense, net. In addition, certain assets and liabilities denominated in currencies other than a foreign subsidiary’s functional currency are reported on the subsidiary’s books in its functional currency, with the impact from exchange rate differences recorded in Other (income) expense, net. Assets and liabilities of foreign operations are translated into U.S. dollars using the exchange rates in effect at the balance sheet date, while income and expenses are translated at the respective average monthly exchange rates during the year.
34

NOTE 1. SUMMARY OF SIGNIFICANT ACCOUNTING POLICIES (Continued)
Gains and losses on foreign currency translations are reported as a component of Other comprehensive (loss) income. The income tax effect of currency translation adjustments is recorded as a component of deferred taxes with an offset to Other comprehensive (loss) income where appropriate.
Effective July 1, 2018, under the requirements of U.S. GAAP, Argentina was designated as a highly inflationary economy, since it has experienced cumulative inflation of approximately 100 percent or more over a three-year period. As a result, beginning July 1, 2018, the U.S. dollar replaced the Argentine peso as the functional currency of the Company’s subsidiaries in Argentina (collectively, “Clorox Argentina”). Consequently, gains and losses from non-U.S. dollar denominated monetary assets and liabilities for Clorox Argentina are recognized in Other (income) expense, net in the consolidated statement of earnings.
Derivative Instruments
The Company’s use of derivative instruments, principally swaps, futures and forward contracts, is limited to non-trading purposes and is designed to partially manage exposure to changes in commodity prices, interest rates and foreign currencies. The Company’s contracts are hedges for transactions with notional amounts and periods consistent with the related exposures and do not constitute investments independent of these exposures.
The changes in the fair value (i.e., gains or losses) of a derivative instrument are recorded as either assets or liabilities in the consolidated balance sheets with an offset to Net earnings or Other comprehensive (loss) income depending on whether, for accounting purposes, it has been designated and qualifies as an accounting hedge and, if so, on the type of hedging relationship. The criteria used to determine if hedge accounting treatment is appropriate are: (a) formal designation and documentation of the hedging relationship, the risk management objective and hedging strategy at hedge inception; (b) eligibility of hedged items, transactions and corresponding hedging instrument; and (c) effectiveness of the hedging relationship both at inception of the hedge and on an ongoing basis in achieving the hedging objectives. For those derivative instruments designated and qualifying as hedging instruments, the Company must designate the hedging instrument either as a fair value hedge or as a cash flow hedge. The Company designates its commodity forward and future contracts for forecasted purchases of raw materials, interest rate contracts for forecasted interest payments, and foreign currency forward contracts for forecasted purchases of inventory as cash flow hedges. During the fiscal years ended June 30, 2022, 2021 and 2020, the Company had no hedging instruments designated as fair value hedges.
For derivative instruments designated and qualifying as cash flow hedges, gains or losses are reported as a component of Other comprehensive (loss) income and reclassified into earnings in the same period or periods during which the hedged transaction affects earnings. From time to time, the Company may have contracts not designated as hedges for accounting purposes, for which it recognizes changes in the fair value in the consolidated statement of earnings in the current period. Cash flows from hedging activities are classified as operating activities in the consolidated statements of cash flows.
Recently Issued Accounting Standards
Recently Adopted Accounting Standards
In December 2019, the Financial Accounting Standards Board (FASB) issued Accounting Standards Update (ASU) No. 2019-12, “Income Taxes (ASC 740): Simplifying the Accounting for Income Taxes,” which removes certain exceptions to the general principles in ASC 740 and amends existing guidance to improve consistent application. Certain amendments must be applied prospectively, certain amendments must be applied on a retrospective basis and certain amendments must be applied on a modified retrospective basis through a cumulative effect adjustment to retained earnings. The Company adopted this standard as of July 1, 2021. The adoption did not have a material impact on the Company’s condensed consolidated financial statements.
35

NOTE 2. BUSINESS ACQUIRED
Saudi Joint Venture Acquisition
On July 9, 2020, the Company increased its investment in each of the two entities comprising its joint venture in the Kingdom of Saudi Arabia (Saudi joint venture). The joint venture offers customers in the Gulf region a range of cleaning and disinfecting products. The Company had previously accounted for its 30 percent investment of $27 as of June 30, 2020, under the equity method of accounting. Subsequent to the closing of this transaction, the Company's total ownership interest in each of the entities increased to 51 percent. The Company has consolidated this joint venture into its consolidated financial statements from the date of acquisition and reflects operations within the International reportable segment. The equity and income attributable to the other joint venture owners is recorded and presented as noncontrolling interests.
The total purchase consideration of $111 consisted of $100 cash paid, which was sourced from operations, and $11 from the net effective settlement of preexisting arrangements between the Company and the joint venture. The assets and liabilities of the joint venture were recorded at their respective estimated fair value as of the acquisition date using generally accepted accounting principles for business combinations. The excess of the purchase price over the fair value of the net identifiable assets acquired was allocated to goodwill in the International reportable segment in the amount of $208. The goodwill is primarily attributable to the synergies expected to arise after the acquisition and reflected the value of further growth anticipated in the Gulf region. None of the goodwill is deductible for tax purposes.
As a result of this transaction, the carrying value of the Company’s previously held equity investment was remeasured to fair value, and resulted in an $85 non-recurring, non-cash gain recorded in Other (income) expense, net in the consolidated statement of earnings and adjusted in Other operating activities in the consolidated statement of cash flows for the first quarter of fiscal year 2021. The fair values of the noncontrolling interests and previously held equity interest were determined using the DCF method under the income approach. Under this approach, the Company estimated future cash flows and discounts these cash flows at a rate of return that reflected the entities’ relative risk.
The purchase price allocation was finalized during the second quarter of fiscal year 2021. The following table summarizes the final purchase price allocation for the fair value of the joint venture’s assets acquired and liabilities assumed and the related deferred income taxes as of the acquisition date. The fair value of the assets acquired and liabilities assumed reflects the final insignificant measurement period adjustments related to goodwill, deferred income taxes and income taxes payable. The finite-lived intangibles acquired primarily represent the Company reacquiring previously licensed trademarks and customer relationships. The weighted-average estimated useful life of intangible assets subject to amortization was 9 years.

| Joint Venture
Goodwill | $ | 208 |
Reacquired rights (included in Other intangible assets, net) | 138 |
Property, plant and equipment | 46 |
Customer relationships (included in Other intangible assets, net) | 10 |
Working capital, net (includes cash acquired of $26) | 34 |
Noncurrent liabilities net | (5) |
Deferred income taxes | (19) |
Total fair value of net assets | 412 |
Less: Fair value of noncontrolling interests | (198) |
Less: Fair value of previously held equity interest | (103) |
Total purchase consideration | $ | 111 |

Included in the Company’s results for both fiscal years 2022 and 2021 was $84 of net sales from the joint venture. Pro forma results reflecting this transaction were not presented because it is not significant to the Company’s consolidated financial results.
36

NOTE 3. INVENTORIES, NET
Inventories, net consisted of the following as of June 30:

| 2022 |  | 2021
Finished goods | $ | 593 |  |  | $ | 543 |
Raw materials and packaging | 191 |  |  | 229 |
Work in process | 16 |  |  | 11 |
LIFO allowances | (40) |  |  | (31) |
Total inventories, net | 760 |  |  | 752 |
Non-current inventories, net (1) | 5 |  |  | — |
Total current inventories, net | $ | 755 |  |  | $ | 752 |

(1) Non-current inventories, net is recorded in Other assets.
The LIFO method was used to value approximately 36% and 34% of inventories as of June 30, 2022 and 2021, respectively. The carrying values for all other inventories are determined on the FIFO method. The effect on earnings of the liquidation of LIFO layers was insignificant for each of the fiscal years ended June 30, 2022, 2021 and 2020.
NOTE 4. PROPERTY, PLANT AND EQUIPMENT, NET
The components of property, plant and equipment, net, consisted of the following as of June 30:

| 2022 |  | 2021
Machinery and equipment | $ | 2,215 |  |  | $ | 2,105 |
Buildings | 729 |  |  | 707 |
Capitalized software costs | 389 |  |  | 368 |
Land and improvements | 166 |  |  | 148 |
Construction in progress | 249 |  |  | 249 |
Computer equipment | 116 |  |  | 107 |
Total | 3,864 |  |  | 3,684 |
Less: Accumulated depreciation and amortization | (2,530) |  |  | (2,382) |
Property, plant and equipment, net | $ | 1,334 |  |  | $ | 1,302 |

Depreciation and amortization expense related to property, plant and equipment, net, was $193, $179 and $166 in fiscal years 2022, 2021 and 2020, respectively, of which $8, $6 and $5 were related to amortization of capitalized software, respectively.
Non-cash capital expenditures were $6, $13 and $7 for fiscal years, 2022, 2021 and 2020, respectively. There were no significant asset retirement obligations recorded and included in Buildings above for both fiscal years 2022 and 2021.
37

NOTE 5. GOODWILL, TRADEMARKS AND OTHER INTANGIBLE ASSETS
The changes in the carrying amount of goodwill by reportable segment for the fiscal years ended June 30, 2022 and 2021 were as follows:

| Goodwill
| Health and Wellness |  | Household |  | Lifestyle |  | International |  | Total
Balance as of June 30, 2020 | $ | 857 |  |  | $ | 85 |  |  | $ | 244 |  |  | $ | 391 |  |  | $ | 1,577 |
Acquisition | — |  |  | — |  |  | — |  |  | 208 |  |  | 208 |
Goodwill impairment | (228) |  |  | — |  |  | — |  |  | — |  |  | (228) |
Effect of foreign currency translation | — |  |  | — |  |  | — |  |  | 18 |  |  | 18 |
Balance as of June 30, 2021 | $ | 629 |  |  | $ | 85 |  |  | $ | 244 |  |  | $ | 617 |  |  | $ | 1,575 |
Effect of foreign currency translation | — |  |  | — |  |  | — |  |  | (17) |  |  | (17) |
Balance as of June 30, 2022 | $ | 629 |  |  | $ | 85 |  |  | $ | 244 |  |  | $ | 600 |  |  | $ | 1,558 |

The changes in the carrying amount of trademarks and other intangible assets for the fiscal years ended June 30, 2022 and 2021 were as follows:

| As of June 30, 2022 |  | As of June 30, 2021
| Gross carrying amount |  | Accumulated amortization / Impairments |  | Net carrying amount |  | Gross carrying amount |  | Accumulated amortization / Impairments |  | Net carrying amount
Trademarks with indefinite lives | $ | 668 |  |  | $ | — |  |  | $ | 668 |  |  | $ | 670 |  |  | $ | — |  |  | $ | 670 |
Trademarks with finite lives | 57 |  |  | 38 |  |  | 19 |  |  | 60 |  |  | 37 |  |  | 23 |
Other intangible assets with finite lives | 577 |  |  | 380 |  |  | 197 |  |  | 593 |  |  | 368 |  |  | 225 |
Total | $ | 1,302 |  |  | $ | 418 |  |  | $ | 884 |  |  | $ | 1,323 |  |  | $ | 405 |  |  | $ | 918 |

Amortization expense relating to the Company’s intangible assets was $31, $32 and $14 for the years ended June 30, 2022, 2021 and 2020, respectively. Estimated amortization expense for these intangible assets is $29, $28, $27, $27 and $27 for fiscal years 2023, 2024, 2025, 2026 and 2027, respectively.
During fiscal year 2021, as a result of lower than expected actual and projected net sales growth and operating performance for the Vitamins, Minerals and Supplements (VMS) SBU, a strategic review was initiated by management that resulted in updated financial and operational plans. These events were considered a triggering event requiring interim impairment assessments to be performed on the VMS reporting unit, indefinite-lived trademarks and other assets. Based on the outcome of these assessments, the following pre-tax impairment charges were recorded during fiscal year 2021 within Goodwill, trademark and other asset impairments:

| VMS Impairment Charge
Goodwill | $ | 228 |
Trademarks, net | 93 |
Other intangible assets, net | 7 |
Property, plant and equipment, net | 1 |
Total | $ | 329 |

The impairment charges were a result of a higher level of competitive activity than originally assumed, accelerated declines in certain channels where the business was over-developed and higher than anticipated investments to grow the business, which adversely affected the assumptions used to determine the fair value of the respective assets held by the VMS reporting unit for growth and the estimates of expenses necessary to achieve that growth. These impairment charges were based on the Company’s estimates regarding the future financial performance of the VMS SBU and macroeconomic factors. In connection with recognizing these impairment charges, the Company recognized tax benefits related to the impairments of $62 due to the partial tax deductibility of these charges.
To determine the fair value of the VMS reporting unit, the Company used the DCF method under the income approach. Under this approach, the Company estimated the future cash flows of the VMS reporting unit and discounted these cash flows at a rate
38

of return that reflected its relative risk. The other key estimates and factors used in the DCF method included, but were not limited to, net sales and expense growth rates, and a terminal growth rate.
To determine the estimated fair values of the VMS related indefinite-lived trademarks, which were included within the Health and Wellness reportable segment, the Company used the relief from royalty income approach. This approach required significant judgments in determining the royalty rates and the assets’ estimated cash flows as well as the appropriate discount rates applied to those cash flows to determine fair value.
Additionally during fiscal year 2021, an impairment charge of $14 was recorded within Cost of products sold related to other intangible assets with finite lives that were no longer expected to be recoverable due to a pending exit from a Professional Products SBU supplier relationship. The remaining carrying value of these assets was $0 following the impairment charge.
No other significant impairments were identified as a result of the Company’s impairment reviews during fiscal year 2021 and no significant impairments were identified during fiscal year 2022 or fiscal year 2020.
39

NOTE 6. ACCOUNTS PAYABLE AND ACCRUED LIABILITIES
Accounts payable and accrued liabilities consisted of the following as of June 30:

| 2022 |  | 2021
Accounts payable | $ | 960 |  |  | $ | 930 |
Compensation and employee benefit costs | 176 |  |  | 219 |
Trade and sales promotion costs | 199 |  |  | 227 |
Dividends | 19 |  |  | 162 |
Other | 115 |  |  | 137 |
Total | $ | 1,469 |  |  | $ | 1,675 |

NOTE 7. DEBT
Short-term borrowings
Notes and loans payable are borrowings that mature in less than one year, primarily consisting of U.S. commercial paper issued by the Company and borrowings under the Company's revolving credit agreements. Notes and loans payable were $237 and $0 as of June 30, 2022 and 2021, respectively.
The weighted average interest rates incurred on average outstanding notes and loans payable during the fiscal years ended June 30, 2022, 2021, and 2020, including fees associated with the Company’s revolving credit agreements, were 0.54%, 0% and 2.49% respectively. The Company had no material outstanding notes and loans payable during the fiscal year ended June 30, 2021.
Long-term borrowings
Long-term debt, carried at face value net of unamortized discounts, premiums and debt issuance costs, included the following as of June 30:

| 2022 |  | 2021
Senior unsecured notes and debentures: |  |  |
3.80%, $300 due November 2021 | $ | — |  |  | $ | 300 |
3.05%, $600 due September 2022 | — |  |  | 599 |
3.50%, $500 due December 2024 | — |  |  | 498 |
3.10%, $400 due October 2027 | 398 |  |  | 398 |
3.90%, $500 due May 2028 | 497 |  |  | 497 |
4.40%, $500 due May 2029 | 493 |  |  | — |
1.80%, $500 due May 2030 | 494 |  |  | 492 |
4.60%, $600 due May 2032 | 592 |  |  | — |
Total | 2,474 |  |  | 2,784 |
Less: Current maturities of long-term debt | — |  |  | 300 |
Long-term debt | $ | 2,474 |  |  | $ | 2,484 |

In May 2022, the Company issued $1,100 in senior notes, including $500 of senior notes with an annual fixed interest rate of 4.40%, payable semi-annually in May and November, final maturity in May 2029 that carry an effective rate of 3.89% (May 2029 senior notes), which includes the impact from the settlement of interest rate contracts in May 2022, and $600 of senior notes with an annual fixed rate of 4.60%, payable semi-annually in May and November, final maturity in May 2032 that carry an effective rate of 3.25% (May 2032 senior notes), which includes the impact from the settlement of interest rate contracts in May 2022. The notes rank equally with all of the Company's existing senior indebtedness. Proceeds from the senior notes were used to redeem prior to maturity $600 of senior notes with an annual fixed interest rate of 3.05% due in September 2022 and $500 of senior notes with an annual fixed interest rate of 3.50% due in December 2024, which were redeemed in June 2022 prior to their maturities, and for general corporate purposes. In connection with the redemption prior to maturity of the $500 of senior notes due in December 2024, the Company recorded a loss on the early extinguishment of debt of $13, which is included in Interest expense in the Consolidated Statement of Earnings, representing the difference paid in cash between the redemption
40

NOTE 7. DEBT (Continued)
price and the carrying amount of the debt extinguished of $5 and the accelerated amortization of losses on settlement of interest rate contracts and issuance costs associated with the debt extinguished of $8.
In November 2021, $300 of the Company’s senior notes with annual fixed interest rate of 3.80% became due and were repaid using commercial paper borrowings.
The weighted average interest rates incurred on average outstanding long-term debt during the fiscal years ended June 30, 2022, 2021 and 2020, were 3.25%, 3.49% and 3.75%, respectively. The weighted average effective interest rates on long-term debt balances as of both June 30, 2022 and 2021 were 3.37% and 3.49%, respectively.
Long-term debt maturities as of June 30, 2022, were $0 in fiscal years 2023 through 2027, and $2,500 thereafter.
Credit arrangements
On March 25, 2022, the Company entered into a new $1,200 revolving credit agreement (the Credit Agreement) that matures in March 2027. The Credit Agreement replaced a prior $1,200 revolving credit agreement (the Prior Credit Agreement) in place since November 2019. The Credit Agreement changed the interest rate benchmark used as a reference rate for borrowings under the Credit Agreement from the London Interbank Offered Rate (LIBOR) to the secured overnight financing rate (SOFR). The Company did not incur any termination fees or penalties in connection with entering the new agreement, which was considered a debt modification. There were no borrowings under either the Credit Agreement or the Prior Credit Agreement as of June 30, 2022 and June 30, 2021, respectively, and the Company believes that borrowings under the new Credit Agreement will continue to be available for general corporate purposes. The Credit Agreement includes certain restrictive covenants and limitations consistent with the previous agreement, with which the Company was in compliance as of June 30, 2022 and June 30, 2021.
The Company’s borrowing capacity under the revolving credit agreements and other financing arrangements as of June 30 was as follows:

| 2022 |  | 2021
Revolving credit facility | $ | 1,200 |  |  | $ | 1,200 |
Foreign and other credit lines | 34 |  |  | 35 |
Total | $ | 1,234 |  |  | $ | 1,235 |

Of the $34 of foreign and other credit lines as of June 30, 2022, $4 was outstanding and the remainder of $30 was available for borrowing. Of the $35 of foreign and other credit lines as of June 30, 2021, $5 was outstanding and the remainder of $30 was available for borrowing.
NOTE 8. OTHER LIABILITIES
Other liabilities consisted of the following as of June 30:

| 2022 |  | 2021
Venture Agreement terminal obligation, net | $ | 468 |  |  | $ | 432 |
Employee benefit obligations | 263 |  |  | 330 |
Taxes | 19 |  |  | 23 |
Environmental liabilities | 23 |  |  | 24 |
Other | 18 |  |  | 25 |
Total | $ | 791 |  |  | $ | 834 |

Venture Agreement
The Company has an agreement with The Procter & Gamble Company (P&G) for the Company’s Glad bags and wraps business. In connection with this agreement, P&G provides research and development (R&D) support to the Glad business. As of June 30, 2022 and 2021, P&G had a 20% interest in the venture. The Company pays a royalty to P&G for its interest in the profits, losses and cash flows, as contractually defined, of the Glad business, which is included in Cost of products sold. In December 2017, the Company and P&G extended the term of the agreement and the related R&D support provided by P&G. The term will expire in January 2026, unless the parties agree, on or prior to January 31, 2025, to further extend the term of the agreement for another seven years or agree to take some other relevant action. The agreement can be terminated under certain
41

NOTE 8. OTHER LIABILITIES (Continued)
circumstances, including at P&G’s option upon a change in control of the Company or, at either party’s option, upon the sale of the Glad business by the Company.
Upon termination of the agreement, the Company is required to purchase P&G’s 20% interest for cash at fair value as established by predetermined valuation procedures. As of June 30, 2022, the estimated fair value of P&G’s interest was $635, of which $468 has been recognized and is reflected in Other liabilities as noted in the table above. The difference between the estimated fair value and the amount recognized, and any future changes in the fair value of P&G’s interest, is charged to Cost of products sold in accordance with the effective interest method over the remaining life of the agreement. Following termination, the Glad business will retain the exclusive core intellectual property licenses contributed by P&G on a royalty-free basis for the licensed products marketed.
NOTE 9. FINANCIAL INSTRUMENTS AND FAIR VALUE MEASUREMENTS
Financial Risk Management and Derivative Instruments
The Company is exposed to certain commodity, foreign currency and interest rate risks related to its ongoing business operations and uses derivative instruments to mitigate its exposure to these risks.
Commodity Price Risk Management
The Company may use commodity exchange-traded futures and over-the-counter swap contracts, which are generally no longer than 2 years, to fix the price of a portion of its forecasted raw material requirements. Commodity purchase contracts are measured at fair value using market quotations obtained from the Chicago Board of Trade commodity futures exchange and commodity derivative dealers.
As of June 30, 2022, the notional amount of commodity derivatives was $27, of which $18 related to soybean oil futures used for the Food products business and $9 related to jet fuel swaps used for the Grilling business. As of June 30, 2021, the notional amount of commodity derivatives was $32, of which $23 related to soybean oil futures and $9 related to jet fuel swaps.
Foreign Currency Risk Management
The Company may also enter into certain over-the-counter derivative contracts to manage a portion of the Company’s forecasted foreign currency exposure associated with the purchase of inventory. These foreign currency contracts generally have durations of no longer than 2 years. The foreign exchange contracts are measured at fair value using information quoted by foreign exchange dealers.
The notional amounts of outstanding foreign currency forward contracts used by the Company’s subsidiaries to hedge forecasted purchases of inventory were $31 and $70, respectively, as of June 30, 2022 and 2021.
Interest Rate Risk Management
The Company may enter into over-the-counter interest rate contracts to fix a portion of the benchmark interest rate prior to the anticipated issuance of fixed rate debt. These interest rate contracts generally have durations of less than 3 years. The interest rate contracts are measured at fair value using information quoted by bond dealers.
The notional amounts of the Company's outstanding interest rate contracts were $0 and $300, respectively, as of June 30, 2022 and 2021. During fiscal year 2022, the Company entered into an additional $650 of interest rate contracts. All contracts represented interest rate swap lock agreements to manage the exposure to interest rate volatility associated with future interest payments on forecasted debt issuance, and were terminated in May 2022 upon issuance of $1,100 in senior notes (See Note 7). These contracts resulted in a $114 gain recorded in Other comprehensive (loss) income, comprised of $25 attributable to the May 2029 senior notes and $89 attributable to the May 2032 senior notes, which is being amortized into Interest expense in the consolidated statement of earnings over the 7-year and 10-year term of the notes.
Commodity, Foreign Exchange and Interest Rate Derivatives
The Company designates its commodity forward and futures contracts for forecasted purchases of raw materials, foreign currency forward contracts for forecasted purchases of inventory, and interest rate contracts for forecasted interest payments as cash flow hedges.
42

NOTE 9. FINANCIAL INSTRUMENTS AND FAIR VALUE MEASUREMENTS (Continued)
The effects of derivative instruments designated as hedging instruments on Other comprehensive (loss) income and Net earnings were as follows during the fiscal years ended June 30:

| Gains (losses) recognized in Other comprehensive (loss) income
| 2022 |  | 2021 |  | 2020
Commodity purchase derivative contracts | $ | 17 |  |  | $ | 21 |  |  | $ | (7) |
Foreign exchange derivative contracts | 1 |  |  | — |  |  | — |
Interest rate derivative contracts | 89 |  |  | 23 |  |  | 2 |
Total | $ | 107 |  |  | $ | 44 |  |  | $ | (5) |

| Location of gains (losses) reclassified from Accumulated other comprehensive net (loss) income into Net earnings | Gains (losses) reclassified from Accumulated other comprehensive net (loss) income and recognized in Net earnings
|  | 2022 |  | 2021 |  | 2020
Commodity purchase derivative contracts | Cost of products sold | $ | 23 |  |  | $ | 1 |  |  | $ | (4) |
Foreign exchange derivative contracts | Cost of products sold | — |  |  | — |  |  | — |
Interest rate derivative contracts | Interest expense | (9) |  |  | (6) |  |  | (6) |
Total |  | $ | 14 |  |  | $ | (5) |  |  | $ | (10) |

The estimated amount of the existing net gain (loss) in Accumulated other comprehensive net (loss) income as of June 30, 2022 that is expected to be reclassified into Net earnings within the next twelve months is $22.
Counterparty Risk Management and Derivative Contract Requirements
The Company utilizes a variety of financial institutions as counterparties for over-the-counter derivative instruments. The Company enters into agreements governing the use of over-the-counter derivative instruments and sets internal limits on the aggregate over-the-counter derivative instrument positions held with each counterparty. Certain terms of these agreements require the Company or the counterparty to post collateral when the fair value of the derivative instruments exceeds contractually defined counterparty liability position limits. Of the over-the-counter derivative instruments in liability positions held as of both June 30, 2022 and 2021, $0 contained such terms. As of both June 30, 2022 and 2021, neither the Company nor any counterparty was required to post any collateral as no counterparty liability position limits were exceeded.
Certain terms of the agreements governing the Company’s over-the-counter derivative instruments require the credit ratings, as assigned by Standard & Poor’s and Moody’s to the Company and its counterparties, to remain at a level equal to or better than the minimum of an investment grade credit rating. If the Company’s credit ratings were to fall below investment grade, the counterparties to the derivative instruments could request full collateralization on derivative instruments in net liability positions. As of both June 30, 2022 and 2021, the Company and each of its counterparties had been assigned investment grade ratings by both Standard & Poor’s and Moody’s.
Certain of the Company’s exchange-traded futures contracts used for commodity price risk management include requirements for the Company to post collateral in the form of a cash margin account held by the Company’s broker for trades conducted on that exchange. As of June 30, 2022 and 2021, the Company maintained cash margin balances related to exchange-traded futures contracts of $1 and $0, respectively, which are classified as Prepaid expenses and other current assets on the consolidated balance sheets.
Trust Assets
The Company holds interests in mutual funds and cash equivalents as part of trust assets related to its nonqualified deferred compensation plans. The participants in the nonqualified deferred compensation plans, who are the Company’s current and former employees, may select among certain mutual funds in which their compensation deferrals are invested in accordance with the terms of the plan and within the confines of the trusts, which hold the marketable securities. The trusts represent variable interest entities for which the Company is considered the primary beneficiary, and, therefore, trust assets are consolidated and included in Other assets in the consolidated balance sheets. The gains and losses on the trust assets are recorded in Other (income) expense, net in the consolidated statement of earnings. The interests in mutual funds are measured at fair value using quoted market prices. The Company has designated these marketable securities as trading investments.
43

NOTE 9. FINANCIAL INSTRUMENTS AND FAIR VALUE MEASUREMENTS (Continued)
As of June 30, 2022, the balance of the trust assets related to the Company’s nonqualified deferred compensation plans decreased by $17 as compared to June 30, 2021.
Fair Value of Financial Instruments
Financial assets and liabilities measured at fair value on a recurring basis in the consolidated balance sheets are required to be classified and disclosed in one of the following three categories of the fair value hierarchy:
Level 1: Quoted market prices in active markets for identical assets or liabilities.
Level 2: Observable market-based inputs or unobservable inputs that are corroborated by market data.
Level 3: Unobservable inputs reflecting the reporting entity’s own assumptions.
As of June 30, 2022 and 2021, the Company’s financial assets and liabilities that were measured at fair value on a recurring basis during the period included derivative financial instruments, which were classified as either Level 1 or Level 2, and trust assets to fund the Company’s nonqualified deferred compensation plans, which were classified as Level 1.
All of the Company's derivative instruments qualify for hedge accounting. The following table provides information about the balance sheet classification and the fair values of the Company's derivative instruments:

|  |  |  |  | 2022 |  | 2021
| Balance sheet classification |  | Fair value hierarchy level |  | Carrying Amount |  | Estimated Fair Value |  | Carrying Amount |  | Estimated Fair Value
Assets |  |  |  |  |  |  |  |  |  |  |
Commodity purchase futures contracts | Prepaid expenses and other current assets |  | 1 |  | $ | — |  |  | $ | — |  |  | $ | 5 |  |  | $ | 5 |
Commodity purchase swaps contracts | Prepaid expenses and other current assets |  | 2 |  | 6 |  |  | 6 |  |  | 4 |  |  | 4 |
Foreign exchange forward contracts | Accounts payable and accrued liabilities |  | 2 |  | 1 |  |  | 1 |  |  | — |  |  | — |
Interest rate contracts | Other assets |  | 2 |  | — |  |  | — |  |  | 24 |  |  | 24 |
|  |  |  |  | $ | 7 |  |  | $ | 7 |  |  | $ | 33 |  |  | $ | 33 |
Liabilities |  |  |  |  |  |  |  |  |  |  |
Commodity purchase futures contracts | Accounts payable and accrued liabilities |  | 1 |  | $ | 1 |  |  | $ | 1 |  |  | $ | — |  |  | $ | — |
|  |  |  |  | $ | 1 |  |  | $ | 1 |  |  | $ | — |  |  | $ | — |

44

NOTE 9. FINANCIAL INSTRUMENTS AND FAIR VALUE MEASUREMENTS (Continued)
The following table provides information about the balance sheet classification and the fair values of the Company's other assets and liabilities for which disclosure of fair value is required:

|  |  |  |  | 2022 |  | 2021
| Balance sheet classification |  | Fair value hierarchy level |  | Carrying Amount |  | Estimated Fair Value |  | Carrying Amount |  | Estimated Fair Value
Assets |  |  |  |  |  |  |  |  |  |  |
Interest-bearing investments, including money market funds | Cash and cash equivalents (1) |  | 1 |  | $ | 86 |  |  | $ | 86 |  |  | $ | 196 |  |  | $ | 196 |
Time deposits | Cash and cash equivalents (1) |  | 2 |  | 4 |  |  | 4 |  |  | 11 |  |  | 11 |
Trust assets for nonqualified deferred compensation plans | Other assets |  | 1 |  | 119 |  |  | 119 |  |  | 136 |  |  | 136 |
|  |  |  |  | $ | 209 |  |  | $ | 209 |  |  | $ | 343 |  |  | $ | 343 |
Liabilities |  |  |  |  |  |  |  |  |  |  |
Notes and loans payable | Notes and loans payable (2) |  | 2 |  | $ | 237 |  |  | $ | 237 |  |  | $ | — |  |  | $ | — |
Current maturities of long-term debt and Long-term debt | Current maturities of long- term debt and Long-term debt (3) |  | 2 |  | 2,474 |  |  | 2,386 |  |  | 2,784 |  |  | 2,963 |
|  |  |  |  | $ | 2,711 |  |  | $ | 2,623 |  |  | $ | 2,784 |  |  | $ | 2,963 |

(1)Cash and cash equivalents are composed of time deposits and other interest-bearing investments, including money market funds with original maturity dates of 90 days or less. Cash and cash equivalents are recorded at cost, which approximates fair value.
(2)Notes and loans payable are composed of outstanding U.S. commercial paper balances and/or amounts drawn on the Company’s credit agreements, all of which are recorded at cost, which approximates fair value.
(3)Current maturities of long-term debt and Long-term debt are recorded at cost. The fair value of Long-term debt, including current maturities, was determined using secondary market prices quoted by corporate bond dealers, and is classified as Level 2.
Furthermore, impairment charges of $343 were recorded during the fiscal year 2021, of which $228, $93, and $22 related to goodwill, certain indefinite-lived trademarks and other assets, respectively. These adjustments were included as non-cash charges in the consolidated statement of earnings. The non-recurring fair values utilized included unobservable Level 3 inputs based on management’s best estimates and assumptions. See Note 5 for additional information.
NOTE 10. OTHER CONTINGENCIES, GUARANTEES AND COMMITMENTS
Contingencies
The Company is involved in certain environmental matters, including response actions at various locations. The Company had recorded liabilities totaling $28 as of both June 30, 2022 and 2021 for its share of aggregate future remediation costs related to these matters.
One matter, which accounted for $14 of the recorded liability as of both June 30, 2022 and 2021, relates to environmental costs associated with one of the Company’s former operations at a site located in Alameda County, California. In November 2016, at the request of regulators and with the assistance of environmental consultants, the Company submitted a Feasibility Study that evaluated various options for managing the site and included estimates of the related costs. Following further discussions with the regulators in 2017, the Company recorded an undiscounted liability for costs estimated to be incurred over a 30-year period, based on one of the options in the Feasibility Study. In September 2021, as a result of an additional study and further discussions with regulators, the Company submitted a Soil Vapor Intrusion Report to the regulators, which has not resulted in a change to the recorded liability. While the Company believes its latest estimates of remediation costs are reasonable, the ultimate remediation requirements are not yet finalized and the regulators could require the Company to implement remediation actions for a longer period or take additional actions, which could include estimated undiscounted costs of up to approximately $28 over an estimated 30-year period, or require the Company to take different actions and incur additional costs.
Another matter in Dickinson County, Michigan, at the site of one of the Company’s former operations for which the Company is jointly and severally liable, accounted for $9 and $10 of the recorded liability as of June 30, 2022 and 2021, respectively. This amount reflects the Company’s agreement to be liable for 24.3% of the aggregate remediation and associated costs for this matter pursuant to a cost-sharing arrangement with a third party. If the third party is unable to pay its share of the response and remediation obligations, the Company may be responsible for such obligations. With the assistance of environmental consultants, the Company maintains an undiscounted liability representing its current best estimate of its share of the capital
45

NOTE 10. OTHER CONTINGENCIES, GUARANTEES AND COMMITMENTS (Continued)
expenditures, maintenance and other costs that may be incurred over an estimated 30-year remediation period. Although it is reasonably possible that the Company’s exposure may exceed the amount recorded for the Dickinson County matter, any amount of such additional exposures, or range of exposures, is not estimable at this time.
The Company’s estimated losses related to these matters are sensitive to a variety of uncertain factors, including the efficacy of any remediation efforts, changes in any remediation requirements and the future availability of alternative clean-up technologies. The Company is subject to various legal proceedings, claims and other loss contingencies, including, without limitation, loss contingencies relating to contractual arrangements (including costs connected to the transition and unwinding of certain supply and manufacturing relationships), product liability, patents and trademarks, advertising, labor and employment, environmental, health and safety and other matters. With respect to these proceedings, claims and other loss contingencies, while considerable uncertainty exists, in the opinion of management at this time, the ultimate disposition of these matters, to the extent not previously provided for, will not have a material adverse effect, either individually or in the aggregate, on the Company’s consolidated financial statements taken as a whole.
Guarantees
In conjunction with divestitures and other transactions, the Company may provide typical indemnifications (e.g., indemnifications for representations and warranties and retention of previously existing environmental, tax and employee liabilities) that have terms that vary in duration and in the potential amount of the total obligation and, in many circumstances, are not explicitly defined. The Company has not made, nor does it believe that it is probable that it will make, any material payments relating to its indemnifications, and believes that any reasonably possible payments would not have a material adverse effect, either individually or in the aggregate, on the Company’s consolidated financial statements taken as a whole.
The Company had not recorded any material liabilities on the aforementioned guarantees as of June 30, 2022 and 2021.
The Company was a party to a letter of credit of $14 as of June 30, 2022 and $11 as of June 30, 2021, primarily related to one of its insurance carriers, of which $0 had been drawn upon.
Commitments
The Company is a party to certain purchase obligations, which are defined as purchase agreements that are enforceable and legally binding and that contain specified or determinable significant terms, including quantity, price and the approximate timing of the transaction. For purchase obligations subject to variable price and/or quantity provisions, an estimate of the price and/or quantity must be made. Examples of the Company’s purchase obligations include contracts to purchase raw materials, commitments to contract manufacturers, commitments for information technology and related services, advertising contracts, capital expenditure agreements, software acquisition and license commitments and service contracts. The Company enters into purchase obligations based on expectations of future business needs. Many of these purchase obligations are flexible to allow for changes in the Company’s business and related requirements. As of June 30, 2022, the Company’s purchase obligations by purchase date were approximately as follows:

Year | Purchase Obligations
2023 | $ | 186 |
2024 | 127 |
2025 | 73 |
2026 | 35 |
2027 | 12 |
Thereafter | 23 |
Total | $ | 456 |

NOTE 11. LEASES
The Company leases various property, plant and equipment, including office, warehousing, manufacturing and research and development facilities and equipment. These leases have remaining lease terms of up to 35 years, inclusive of renewal or termination options that the Company is reasonably certain to exercise. The Company’s lease agreements do not contain any material residual value guarantees or material restrictive covenants.
46

NOTE 11. LEASES (Continued)
Supplemental balance sheet information related to the Company’s leases as of June 30 was as follows:

| Balance sheet classification | 2022 |  | 2021
Operating leases |  |  |  |
Right-of-use assets | Operating lease right-of-use assets | $ | 342 |  |  | $ | 332 |
Current lease liabilities | Current operating lease liabilities | $ | 78 |  |  | $ | 81 |
Non-current lease liabilities | Long-term operating lease liabilities | 314 |  |  | 301 |
Total operating lease liabilities |  | $ | 392 |  |  | $ | 382 |
Finance leases |  |  |  |
Right-of-use assets | Other assets | $ | 18 |  |  | $ | 19 |
Current lease liabilities | Accounts payable and accrued liabilities | $ | 6 |  |  | $ | 5 |
Non-current lease liabilities | Other liabilities | 13 |  |  | 15 |
Total finance lease liabilities |  | $ | 19 |  |  | $ | 20 |

Components of lease cost were as follows for the fiscal years ended June 30:

|  | 2022 |  | 2021
Operating lease cost |  | $ | 83 |  |  | $ | 73 |
Finance lease cost: |  |  |  |
Amortization of right-of-use assets |  | $ | 9 |  |  | $ | 4 |
Interest on lease liabilities |  | 1 |  |  | — |
Total finance lease cost |  | $ | 10 |  |  | $ | 4 |
Variable lease cost |  | $ | 80 |  |  | $ | 39 |
Short term lease cost |  | $ | 6 |  |  | $ | 2 |

Supplemental cash flow information and non-cash activity related to the Company’s leases were as follows during fiscal years ended June 30:

| 2022 |  | 2021
Cash paid for amounts included in the measurement of lease liabilities: |  |  |
Operating cash flows from operating leases, net | $ | 84 |  |  | $ | 75 |
Operating cash flows from finance leases | 1 |  |  | — |
Financing cash flows from finance leases | 9 |  |  | 3 |
Right-of-use assets obtained in exchange for lease obligations: |  |  |
Operating leases | $ | 94 |  |  | $ | 106 |
Finance leases | 18 |  |  | 7 |

Weighted-average remaining lease term and discount rate for the Company’s leases were as follows as of fiscal year ended June 30:

| 2022
Weighted-average remaining lease term: |
Operating leases | 6 years
Finance leases | 4 years
Weighted-average discount rate: |
Operating leases | 2.4 | %
Finance leases | 4.1 | %

47

NOTE 11. LEASES (Continued)
Maturities of lease liabilities by fiscal year for the Company’s leases as of June 30, 2022 were as follows:

Year | Operating leases |  | Finance leases
2023 | $ | 80 |  |  | $ | 7 |
2024 | 78 |  |  | 5 |
2025 | 67 |  |  | 3 |
2026 | 55 |  |  | 2 |
2027 | 45 |  |  | 1 |
Thereafter | 101 |  |  | 2 |
Total lease payments | $ | 426 |  |  | $ | 20 |
Less: Imputed interest | (34) |  |  | (1) |
Total lease liabilities | $ | 392 |  |  | $ | 19 |

Operating and finance lease payments presented in the table above exclude $39 and $0, respectively, of minimum lease payments signed but not yet commenced as of June 30, 2022.
On May 25, 2022, the Company completed an asset sale-leaseback transaction on a plant in Ontario, Canada. The Company received proceeds of $16, net of selling costs, which had a carrying value of $2, and resulted in a $14 gain on the transaction which was recognized in Other (income) expense, net. The leaseback is accounted for as an operating lease. The term of the lease is 10 years, with the option to terminate the lease at 7 years.
NOTE 12. STOCKHOLDERS' EQUITY
On November 18, 2020 the Company retired 28 million shares of its treasury stock. These shares are now authorized but unissued. There was no effect on the Company’s overall equity position as a result of the retirement.
Dividends per share paid to Clorox stockholders during the fiscal years ended June 30 were as follows:

| 2022 |  | 2021 |  | 2020
Dividends per share paid | $ | 4.64 |  |  | $ | 4.44 |  |  | $ | 4.24 |

On July 12, 2022, a cash dividend was declared in the amount of $1.18 per share payable on August 12, 2022 to common stockholders of record as of the close of business on July 27, 2022.
48

NOTE 12. STOCKHOLDERS' EQUITY (Continued)
Accumulated Other Comprehensive Net (Loss) Income
Changes in Accumulated other comprehensive net (loss) income attributable to Clorox by component were as follows for the fiscal years ended June 30:

| Foreign currency translation adjustments |  | Net unrealized gains (losses) on derivatives |  | Pension and postretirement benefit adjustments |  | Accumulated other comprehensive net (loss) income
Balance June 30, 2019 | $ | (414) |  |  | $ | (23) |  |  | $ | (165) |  |  | $ | (602) |
Other comprehensive (loss) income before reclassifications | (35) |  |  | (5) |  |  | (16) |  |  | (56) |
Amounts reclassified from Accumulated other comprehensive net (loss) income | — |  |  | 10 |  |  | 7 |  |  | 17 |
Income tax benefit (expense) | (1) |  |  | — |  |  | 2 |  |  | 1 |
Net current period other comprehensive (loss) income | (36) |  |  | 5 |  |  | (7) |  |  | (38) |
Balance June 30, 2020 | (450) |  |  | (18) |  |  | (172) |  |  | (640) |
Other comprehensive (loss) income before reclassifications | 53 |  |  | 44 |  |  | (2) |  |  | 95 |
Amounts reclassified from Accumulated other comprehensive net (loss) income | (5) |  |  | 5 |  |  | 14 |  |  | 14 |
Income tax benefit (expense) | (1) |  |  | (10) |  |  | (4) |  |  | (15) |
Net current period other comprehensive (loss) income | 47 |  |  | 39 |  |  | 8 |  |  | 94 |
Balance June 30, 2021 | (403) |  |  | 21 |  |  | (164) |  |  | (546) |
Other comprehensive (loss) income before reclassifications | (45) |  |  | 107 |  |  | 1 |  |  | 63 |
Amounts reclassified from Accumulated other comprehensive net (loss) income | — |  |  | (14) |  |  | 15 |  |  | 1 |
Income tax benefit (expense) | — |  |  | 7 |  |  | (4) |  |  | 3 |
Net current period other comprehensive (loss) income | (45) |  |  | 100 |  |  | 12 |  |  | 67 |
Balance June 30, 2022 | $ | (448) |  |  | $ | 121 |  |  | $ | (152) |  |  | $ | (479) |

Included in foreign currency translation adjustments are re-measurement losses on long-term intercompany loans where settlement is not planned or anticipated in the foreseeable future. There were $0, $11, and $0 associated with these loans reclassified from Accumulated other comprehensive net (loss) income for the fiscal years ended June 30, 2022, 2021, and 2020, respectively.
NOTE 13. NET EARNINGS PER SHARE (EPS)
The following is the reconciliation of the weighted average number of shares outstanding (in thousands) used to calculate basic net EPS to those used to calculate diluted net EPS for the fiscal years ended June 30:

| 2022 |  | 2021 |  | 2020
Basic | 123,113 |  |  | 125,570 |  |  | 125,828 |
Dilutive effect of stock options and other | 793 |  |  | 1,729 |  |  | 1,843 |
Diluted | 123,906 |  |  | 127,299 |  |  | 127,671 |
Antidilutive stock options and other | 2,448 |  |  | 476 |  |  | — |

Basic net earnings per share and Diluted net earnings per share are calculated on Net earnings attributable to Clorox.
49

NOTE 14. STOCK-BASED COMPENSATION PLANS
In November 2021, the Company’s stockholders voted to approve the amended and restated 2005 Stock Incentive Plan (the Plan). The Plan permits the Company to grant various nonqualified stock-based compensation awards, including stock options, restricted stock, performance shares, deferred stock units, stock appreciation rights and other stock-based awards. The Plan as amended and restated provides that the maximum number of shares which may be issued under the Plan will be 5 million common shares that may be issued for stock-based compensation purposes. As of June 30, 2022, the Company was authorized to grant up to approximately 5 million common shares, plus additional shares equal to shares that are potentially deliverable under an award that expires or are canceled, forfeited or settled without the delivery of shares, under the Plan. As of June 30, 2022, approximately 4 million common shares remained available for grant.
Compensation cost and the related income tax benefit recognized for stock-based compensation plans were classified as indicated below for the fiscal years ended June 30:

| 2022 |  | 2021 |  | 2020
Cost of products sold | $ | 6 |  |  | $ | 6 |  |  | $ | 5 |
Selling and administrative expenses | 42 |  |  | 40 |  |  | 41 |
Research and development costs | 4 |  |  | 4 |  |  | 4 |
Total compensation costs | $ | 52 |  |  | $ | 50 |  |  | $ | 50 |
Related income tax benefit | $ | 12 |  |  | $ | 12 |  |  | $ | 12 |

Cash received during fiscal years 2022, 2021 and 2020 from stock options exercised under all stock-based payment arrangements was $35, $133 and $176, respectively. The Company issues shares for stock-based compensation plans from treasury stock. The Company may repurchase stock under its Evergreen Program to offset the estimated impact of dilution related to stock-based awards.
Details regarding the valuation and accounting for stock options, restricted stock awards, performance shares and deferred stock units for non-employee directors follow.
Stock Options
The fair value of each stock option award granted during fiscal years 2022, 2021 and 2020 was estimated on the date of grant using the Black-Scholes valuation model and assumptions noted in the following table:

| 2022 |  | 2021 |  | 2020
Expected life | 5.4 years |  | 5.3 to 5.4 years |  | 5.4 years
Weighted-average expected life | 5.4 years |  | 5.4 years |  | 5.4 years
Expected volatility | 21.7% to 25.0% |  | 21.4% to 23.2% |  | 18.7%
Weighted-average volatility | 21.8% |  | 21.9% |  | 18.7%
Risk-free interest rate | 0.9% to 2.1% |  | 0.3% to 0.5% |  | 1.7%
Weighted-average risk-free interest rate | 0.9% |  | 0.3% |  | 1.7%
Dividend yield | 2.9% to 3.7% |  | 2.1% to 2.3% |  | 2.8%
Weighted-average dividend yield | 2.9% |  | 2.1% |  | 2.8%

The expected life of the stock options is based on historical exercise patterns. The expected volatility is based on implied volatility from publicly traded options on the Company’s stock at the date of grant, historical implied volatility of the Company’s publicly traded options and other factors. The risk-free interest rate is based on the implied yield on a U.S. Treasury zero-coupon issue with a remaining term equal to the expected term of the option. The dividend yield is based on the projected annual dividend payment per share, divided by the stock price at the date of grant.
50

Details of the Company’s stock option activities are summarized below:

| Number of Shares (In thousands) |  | Weighted- Average Exercise Price per Share |  | Average Remaining Contractual Life |  | Aggregate Intrinsic Value
Options outstanding as of June 30, 2021 | 4,020 |  |  | $ | 139 |  |  | 6 years |  | $ | 179 |
Granted | 669 |  |  | 163 |  |  |  |  |
Exercised | 317 |  |  | 110 |  |  |  |  |
Canceled | 174 |  |  | 165 |  |  |  |  |
Options outstanding as of June 30, 2022 | 4,198 |  |  | $ | 144 |  |  | 5 years |  | $ | 49 |
Options vested as of June 30, 2022 | 2,861 |  |  | $ | 131 |  |  | 4 years |  | $ | 49 |

The weighted-average fair value per share of each option granted during fiscal years 2022, 2021 and 2020, estimated at the grant date using the Black-Scholes option pricing model, was $22.26, $30.90 and $20.03, respectively. The total intrinsic value of options exercised in fiscal years 2022, 2021 and 2020 was $18, $109 and $145, respectively.
Stock option awards outstanding as of June 30, 2022, have been granted at prices that are equal to the market value of the stock on the date of grant. Stock option grants generally vest over 4 years and expire no later than 10 years after the grant date. The Company recognizes compensation expense on a straight-line basis over the vesting period. As of June 30, 2022, there was $12 of total unrecognized compensation cost related to non-vested options, which is expected to be recognized over a remaining weighted-average vesting period of 1 year, subject to forfeiture changes.
Restricted Stock Awards
The fair value of restricted stock awards is estimated on the date of grant based on the market price of the stock and is amortized to compensation expense on a straight-line basis over the related vesting periods, which are generally 3 to 4 years. The total number of restricted stock awards expected to vest is adjusted by actual and estimated forfeitures. Restricted stock awards receive dividend distributions earned during the vesting period upon vesting.
As of June 30, 2022, there was $34 of total unrecognized compensation cost related to non-vested restricted stock awards, which is expected to be recognized over a remaining weighted-average vesting period of 1 year. The total fair value of the shares that vested in each of the fiscal years 2022, 2021 and 2020 was $20, $15 and $9, respectively. The weighted-average grant-date fair value of awards granted was $157.50, $210.78 and $156.25 per share for fiscal years 2022, 2021 and 2020, respectively.
A summary of the status of the Company’s restricted stock awards is presented below:

| Number of Shares (In thousands) |  | Weighted-Average Grant Date Fair Value per Share
Restricted stock awards as of June 30, 2021 | 315 |  |  | $ | 178 |
Granted | 261 |  |  | 157 |
Vested | 118 |  |  | 167 |
Forfeited | 46 |  |  | 177 |
Restricted stock awards as of June 30, 2022 | 412 |  |  | $ | 168 |

Performance Shares
As of June 30, 2022, there was $13 in unrecognized compensation cost related to non-vested performance shares that is expected to be recognized over a remaining weighted-average performance period of 1 year. The weighted-average grant-date fair value of awards granted was $162.46, $212.00 and $155.54 per share for fiscal years 2022, 2021 and 2020, respectively.
51

A summary of the status of the Company’s performance share awards is presented below:

| Number of Shares (In thousands) |  | Weighted-Average Grant Date Fair Value per Share
Performance share awards as of June 30, 2021 | 353 |  |  | $ | 146 |
Granted | 117 |  |  | $ | 162 |
Distributed | 129 |  |  | $ | 118 |
Forfeited | 28 |  |  | $ | 169 |
Performance share awards as of June 30, 2022 | 313 |  |  | $ | 162 |
Performance shares vested and deferred as of June 30, 2022 | 58 |  |  | $ | 110 |

The non-vested performance shares outstanding as of June 30, 2022 and 2021 were 255,000 and 241,000, respectively, and the weighted average grant date fair value was $173.38 and $172.04 per share, respectively. During fiscal year 2022, 74,000 shares vested. The total fair value of shares vested was $11, $26 and $26 during fiscal years 2022, 2021 and 2020, respectively. Upon vesting, the recipients of the grants receive the distribution as shares or, if previously elected by eligible recipients, as deferred stock. Deferred shares continue to earn dividends, which are also deferred.
Deferred Stock Units for Nonemployee Directors
Nonemployee directors receive annual grants of deferred stock units under the Company’s director compensation program and can elect to receive all or a portion of their annual retainers and fees in the form of deferred stock units. The deferred stock units receive dividend distributions, which are reinvested as deferred stock units, and are recognized at their fair value on the date of grant. Each deferred stock unit represents the right to receive one share of the Company’s common stock following the completion of a director’s service.
During fiscal year 2022, the Company granted 15,000 deferred stock units, reinvested dividends of 5,000 units and distributed 49,000 shares, which had a weighted-average fair value on the grant date of $167.19, $159.37 and $93.60 per share, respectively. As of June 30, 2022, 145,000 units were outstanding, which had a weighted-average fair value on the grant date of $118.99 per share.
NOTE 15. OTHER (INCOME) EXPENSE, NET
The major components of Other (income) expense, net, for the fiscal years ended June 30 were:

| 2022 |  | 2021 |  | 2020
Amortization of trademarks and other intangible assets | $ | 31 |  |  | $ | 31 |  |  | $ | 13 |
Trust investment (gains) losses, net | 21 |  |  | (25) |  |  | (3) |
Net periodic benefit cost | 16 |  |  | 15 |  |  | 10 |
Foreign exchange transaction (gains) losses, net | 3 |  |  | 10 |  |  | 7 |
Income from equity investees | (6) |  |  | (5) |  |  | (20) |
Interest income | (5) |  |  | (5) |  |  | (2) |
Gain on previously held equity investment (1) | — |  |  | (85) |  |  | — |
Gain on sale-leaseback transaction | (14) |  |  | — |  |  | — |
Indemnity settlement from past acquisition | — |  |  | — |  |  | (15) |
Other | (9) |  |  | (8) |  |  | — |
Total | $ | 37 |  |  | $ | (72) |  |  | $ | (10) |

(1) Non-recurring, non-cash gain from the remeasurement of the Company’s previously held investment in its Saudi joint venture (see Note 2).
52

NOTE 16. INCOME TAXES
The provision for income taxes, by tax jurisdiction, consisted of the following for the fiscal years ended June 30:

| 2022 |  | 2021 |  | 2020
Current |  |  |  |  |
Federal | $ | 71 |  |  | $ | 146 |  |  | $ | 171 |
State | 17 |  |  | 26 |  |  | 32 |
Foreign | 43 |  |  | 41 |  |  | 45 |
Total current | $ | 131 |  |  | $ | 213 |  |  | $ | 248 |
Deferred |  |  |  |  |
Federal | $ | 6 |  |  | $ | (26) |  |  | $ | 13 |
State | (2) |  |  | (9) |  |  | (5) |
Foreign | 1 |  |  | 3 |  |  | (10) |
Total deferred | 5 |  |  | (32) |  |  | (2) |
Total | $ | 136 |  |  | $ | 181 |  |  | $ | 246 |

The components of Earnings before income taxes, by tax jurisdiction, consisted of the following for the fiscal years ended June 30:

| 2022 |  | 2021 |  | 2020
United States | $ | 483 |  |  | $ | 696 |  |  | $ | 1,041 |
Foreign | 124 |  |  | 204 |  |  | 144 |
Total | $ | 607 |  |  | $ | 900 |  |  | $ | 1,185 |

A reconciliation of the statutory federal income tax rate to the Company’s effective tax rate on operations follows for the fiscal years ended June 30:

| 2022 |  | 2021 |  | 2020
Statutory federal tax rate | 21.0 | % |  | 21.0 | % |  | 21.0 | %
State taxes (net of federal tax benefits) | 1.9 |  |  | 1.5 |  |  | 1.7 |
Foreign tax rate differential | 3.1 |  |  | 0.2 |  |  | 0.9 |
Federal excess tax benefits | (0.9) |  |  | (2.7) |  |  | (2.4) |
Net U.S. tax on foreign income | (1.7) |  |  | (0.5) |  |  | (0.2) |
Other differences | (1.0) |  |  | 0.6 |  |  | (0.2) |
Effective tax rate | 22.4 | % |  | 20.1 | % |  | 20.8 | %

Per U.S. GAAP, foreign withholding taxes are provided on unremitted foreign earnings that are not indefinitely reinvested at the time the earnings are generated. The Company regularly reviews and assesses whether there are any changes to its indefinite reinvestment assertion. None of the undistributed earnings of its foreign subsidiaries were indefinitely reinvested. As a result, the Company is providing foreign withholding taxes on the undistributed earnings of all foreign subsidiaries where applicable. These withholding taxes had no significant impact on the Company’s consolidated results.
53

NOTE 16. INCOME TAXES (Continued)
The components of net deferred tax assets (liabilities) as of June 30 are shown below:

| 2022 |  | 2021
Deferred tax assets |  |  |
Compensation and benefit programs | $ | 100 |  |  | $ | 104 |
Net operating loss and tax credit carryforwards | 93 |  |  | 85 |
Operating and finance lease liabilities | 98 |  |  | 100 |
Accruals and reserves | 35 |  |  | 39 |
Basis difference related to the Venture Agreement | 19 |  |  | 19 |
Inventory costs | 25 |  |  | 18 |
Other | 13 |  |  | 15 |
Subtotal | 383 |  |  | 380 |
Valuation allowance | (52) |  |  | (42) |
Total deferred tax assets | $ | 331 |  |  | $ | 338 |
Deferred tax liabilities |  |  |
Fixed and intangible assets | $ | (242) |  |  | $ | (232) |
Lease right-of-use assets | (91) |  |  | (94) |
Other | (29) |  |  | (41) |
Total deferred tax liabilities | (362) |  |  | (367) |
Net deferred tax assets (liabilities) | $ | (31) |  |  | $ | (29) |

The Company reviews its deferred tax assets for recoverability on a quarterly basis. A valuation allowance is established when the Company believes that it is more likely than not that some portion of its deferred tax assets will not be realized. Valuation allowances have been provided to reduce deferred tax assets to amounts considered recoverable. Details of the valuation allowance were as follows as of June 30:

| 2022 |  | 2021 |  | 2020
Valuation allowance at beginning of year | $ | (42) |  |  | $ | (38) |  |  | $ | (44) |
Net decrease/(increase) for other foreign deferred tax assets | (1) |  |  | (1) |  |  | 1 |
Net decrease/(increase) for foreign and U.S. net operating loss carryforwards and tax credits | (9) |  |  | (3) |  |  | 5 |
Valuation allowance at end of year | $ | (52) |  |  | $ | (42) |  |  | $ | (38) |

As of June 30, 2022, the Company had foreign tax credit carryforwards of $27 for U.S. income tax purposes with expiration dates between fiscal years 2025 and 2032. Tax credit carryforwards in U.S. jurisdictions of $2 have expiration dates between fiscal year 2023 and 2032. Tax credit carryforwards in U.S. jurisdictions of $2 can be carried forward indefinitely. Tax credit carryforwards in foreign jurisdictions of $28 can be carried forward indefinitely. Tax benefits from net operating loss carryforwards in U.S. jurisdictions of $3 have expiration dates between fiscal years 2030 and 2041. Tax benefits from net operating loss carryforwards in U.S. jurisdictions of $4 can be carried forward indefinitely. Tax benefits from foreign net operating loss carryforwards of $19 have expiration dates between fiscal years 2023 and 2036. Tax benefits from foreign net operating loss carryforwards of $8 can be carried forward indefinitely.
The Company files income tax returns in the U.S. federal and various state, local and foreign jurisdictions. The federal statute of limitations has expired for all tax years through June 30, 2015. Various income tax returns in state and foreign jurisdictions are currently in the process of examination.
The Company recognizes interest and penalties related to uncertain tax positions as a component of income tax expense. As of June 30, 2022 and 2021, the total balance of accrued interest and penalties related to uncertain tax positions was $2 and $2, respectively. Interest and penalties related to uncertain tax positions included in income tax expense resulted in a net benefit of $0 in fiscal year 2022, a net benefit of $0 in fiscal year 2021 and a net benefit of $2 in fiscal year 2020.
54

NOTE 16. INCOME TAXES (Continued)
The following is a reconciliation of the beginning and ending amounts of the Company’s gross unrecognized tax benefits:

| 2022 |  | 2021 |  | 2020
Unrecognized tax benefits at beginning of year | $ | 21 |  |  | $ | 22 |  |  | $ | 31 |
Gross increases - tax positions in prior periods | — |  |  | 1 |  |  | 1 |
Gross decreases - tax positions in prior periods | (7) |  |  | (5) |  |  | (11) |
Gross increases - current period tax positions | 4 |  |  | 3 |  |  | 4 |
Gross decreases - current period tax positions | — |  |  | — |  |  | — |
Lapse of applicable statute of limitations | (1) |  |  | — |  |  | (1) |
Settlements | — |  |  | — |  |  | (2) |
Unrecognized tax benefits at end of year | $ | 17 |  |  | $ | 21 |  |  | $ | 22 |

Included in the balance of unrecognized tax benefits as of June 30, 2022, 2021 and 2020, were potential benefits of $14, $17 and $17, respectively, which if recognized, would affect the effective tax rate. Unrecognized tax benefits are not expected to significantly increase or decrease within the next 12 months.
NOTE 17. EMPLOYEE BENEFIT PLANS
Retirement Income Plans
The Company has various retirement income plans for eligible domestic and international employees. As of June 30, 2022 and 2021, the domestic retirement income plans were frozen and the benefits of the domestic retirement income plans were generally based on either employee years of service and compensation or a stated dollar amount per year of service.
The Company contributed $15, $14 and $13 to its domestic retirement income plans during fiscal years 2022, 2021 and 2020, respectively. The Company’s funding policy is to contribute amounts sufficient to meet benefit payments and minimum funding requirements as set forth in employee benefit tax laws plus additional amounts as the Company may determine to be appropriate.
The Company has a domestic qualified pension plan (the Plan). The Plan is frozen for all participants. The Plan generally was frozen effective June 30, 2011 for all employees, except for certain collectively bargained employees, whose Plan freeze was effective January 1, 2019. As a result of the Plan freeze, no employees are eligible to commence participation in the Plan or accrue any additional benefits under the Plan.
On May 17, 2022, the Company’s Board of Directors approved a resolution to terminate the Plan. The amendment will allow the settlement of the pension obligation with either a lump sum payout or a purchased annuity. It is expected to take 18 to 24 months to complete the termination from the date of the approved resolution to terminate the Plan.
As of June 30, 2022, the Company reported net unrealized losses of $139, net of tax, in Accumulated other comprehensive net (loss) income on its consolidated balance sheet related to the Plan. These net unrealized losses will be recognized in the Company’s consolidated statement of income as payments are made to settle lump sum elections and to purchase group annuity contracts. Final settlement is dependent on market conditions, which could affect discount rates and returns on plan assets as well as final elections received from plan participants. The completion of the process of offering and accepting lump sum elections are dependent on when certain regulatory approvals are obtained. Currently, there is not enough information available to determine the ultimate charge of the termination.
Retirement Health Care Plans
The Company provides certain health care benefits for employees who meet age, participation and length of service requirements at retirement. The plans pay stated percentages of covered expenses after annual deductibles have been met or stated reimbursements up to a specified dollar subsidy amount. Benefits paid take into consideration payments by Medicare for the domestic plan. The plans are funded as claims are paid, and the Company has the right to modify or terminate certain plans.
55

NOTE 17. EMPLOYEE BENEFIT PLANS (Continued)
Benefit Obligation and Funded Status
Summarized information for the Company’s retirement income and retirement health care plans as of and for the fiscal years ended June 30 is as follows:

| Retirement Income |  | Retirement Health Care
| 2022 |  | 2021 |  | 2022 |  | 2021
Change in benefit obligations: |  |  |  |  |  |  |
Benefit obligation as of beginning of year | $ | 621 |  |  | $ | 628 |  |  | $ | 36 |  |  | $ | 36 |
Service cost | 1 |  |  | 2 |  |  | — |  |  | — |
Interest cost | 15 |  |  | 15 |  |  | 1 |  |  | 1 |
Actuarial loss (gain) | (66) |  |  | 12 |  |  | (7) |  |  | — |
Plan amendments | (7) |  |  | — |  |  | — |  |  | — |
Translation and other adjustments | (6) |  |  | 8 |  |  | — |  |  | 1 |
Plan settlement | (13) |  |  | (12) |  |  | — |  |  | — |
Benefits paid | (32) |  |  | (32) |  |  | (2) |  |  | (2) |
Benefit obligation as of end of year | $ | 513 |  |  | $ | 621 |  |  | $ | 28 |  |  | $ | 36 |
Change in plan assets: |  |  |  |  |  |  |
Fair value of assets as of beginning of year | $ | 506 |  |  | $ | 507 |  |  | $ | — |  |  | $ | — |
Actual return on plan assets | (63) |  |  | 26 |  |  | — |  |  | — |
Employer contributions | 15 |  |  | 15 |  |  | 2 |  |  | 2 |
Plan Settlement | (13) |  |  | (12) |  |  | — |  |  | — |
Benefits paid | (32) |  |  | (32) |  |  | (2) |  |  | (2) |
Translation and other adjustments | (1) |  |  | 2 |  |  | — |  |  | — |
Fair value of plan assets as of end of year | 412 |  |  | 506 |  |  | — |  |  | — |
Accrued benefit cost, net funded status | $ | (101) |  |  | $ | (115) |  |  | $ | (28) |  |  | $ | (36) |

Amount recognized in the balance sheets consists of: |  |  |  |  |  |  |
Pension benefit assets | $ | 30 |  |  | $ | 61 |  |  | $ | — |  |  | $ | — |
Current accrued benefit liability | (12) |  |  | (12) |  |  | (2) |  |  | (2) |
Non-current accrued benefit liability | (119) |  |  | (164) |  |  | (26) |  |  | (34) |
Accrued benefit cost, net | $ | (101) |  |  | $ | (115) |  |  | $ | (28) |  |  | $ | (36) |

For the retirement income plans, the benefit obligation is the projected benefit obligation (PBO). For the retirement health care plan, the benefit obligation is the accumulated benefit obligation (ABO).
The ABO for all retirement income plans was $512, $618 and $626 as of June 30, 2022, 2021 and 2020, respectively.
Retirement income plans with ABO or PBO in excess of plan assets as of June 30 were as follows:

| ABO Exceeds the Fair Value of Plan Assets | PBO Exceeds the Fair Value of Plan Assets
| 2022 |  | 2021 | 2022 | 2021
Projected benefit obligation | $ | 133 |  |  | $ | 176 |  | $ | 133 |  | $ | 178 |
Accumulated benefit obligation | 132 |  |  | 174 |  | 132 |  | 175 |
Fair value of plan assets | 2 |  |  | — |  | 2 |  | 2 |

56

NOTE 17. EMPLOYEE BENEFIT PLANS (Continued)
Net Periodic Benefit Cost
The net cost of the retirement income and health care plans for the fiscal years ended June 30 included the following components:

| Retirement Income |  | Retirement Health Care
| 2022 |  | 2021 |  | 2020 |  | 2022 |  | 2021 |  | 2020
Service cost | $ | 1 |  |  | $ | 2 |  |  | $ | 1 |  |  | $ | — |  |  | $ | — |  |  | $ | — |
Interest cost | 15 |  |  | 15 |  |  | 20 |  |  | 1 |  |  | 1 |  |  | 1 |
Expected return on plan assets | (15) |  |  | (16) |  |  | (19) |  |  | — |  |  | — |  |  | — |
Settlement loss recognized | 7 |  |  | 5 |  |  | — |  |  | — |  |  | — |  |  | — |
Amortization of unrecognized items | 9 |  |  | 11 |  |  | 10 |  |  | (1) |  |  | (2) |  |  | (3) |
Total | $ | 17 |  |  | $ | 17 |  |  | $ | 12 |  |  | $ | — |  |  | $ | (1) |  |  | $ | (2) |

Service cost component of the net periodic benefit cost is reflected in employee benefit costs, all other components are reflected in Other (income) expenses, net.
Items not yet recognized as a component of postretirement expense as of June 30, 2022, consisted of:

| Retirement Income |  | Retirement Health Care
Net actuarial loss (gain) | $ | 222 |  |  | $ | (15) |
Prior service benefit | (7) |  |  | — |
Net deferred income tax (assets) liabilities | (51) |  |  | 3 |
Accumulated other comprehensive loss (income) | $ | 164 |  |  | $ | (12) |

Net actuarial loss (gain) recorded in Accumulated other comprehensive net (loss) income for the fiscal year ended June 30, 2022, included the following:

| Retirement Income |  | Retirement Health Care
Net actuarial loss (gain) as of beginning of year | $ | 226 |  |  | $ | (10) |
Amortization during the year | (16) |  |  | 1 |
Loss (gain) during the year | 12 |  |  | (6) |
Net actuarial loss (gain) as of end of year | $ | 222 |  |  | $ | (15) |

The Company uses the straight-line amortization method for unrecognized prior service costs and benefits.
Assumptions
Weighted-average assumptions used to estimate the actuarial present value of benefit obligations were as follows as of June 30:

| Retirement Income |  | Retirement Health Care
| 2022 |  | 2021 |  | 2022 |  | 2021
Discount rate | 3.72 | % |  | 2.56 | % |  | 4.65 | % |  | 2.61 | %
Rate of compensation increase | 3.09 | % |  | 3.02 | % |  | n/a |  | n/a
Interest crediting rate | 2.69 | % |  | 2.57 | % |  | n/a |  | n/a

57

NOTE 17. EMPLOYEE BENEFIT PLANS (Continued)
Weighted-average assumptions used to estimate the retirement income and retirement health care costs were as follows as of June 30:

| Retirement Income
| 2022 |  | 2021 |  | 2020
Discount rate | 2.56 | % |  | 2.45 | % |  | 3.41 | %
Rate of compensation increase | 3.02 | % |  | 2.92 | % |  | 2.86 | %
Expected return on plan assets | 3.00 | % |  | 3.08 | % |  | 3.95 | %
Interest crediting rate | 2.57 | % |  | 1.92 | % |  | 3.01 | %
| Retirement Health Care
| 2022 |  | 2021 |  | 2020
Discount rate | 2.61 | % |  | 2.51 | % |  | 3.35 | %

The expected long-term rate of return assumption is based on prospective returns according to the fund’s current target asset allocation.
The actuarial benefit obligation gain incurred during fiscal year 2022 was primarily driven by increases in the discount rates for the retirement plans, partially offset by the domestic qualified plan reflecting plan termination lump sum window and annuity buyout assumptions. The actuarial benefit obligation loss during fiscal year 2021 was primarily driven by the increase in assumed interest crediting rate, partially offset by asset gains and increase in the discount rate.
Expected Benefit Payments
Expected benefit payments for the Company’s retirement income and retirement health care plans as of June 30, 2022, were as follows:

| Retirement Income |  | Retirement Health Care
2023 | $ | 46 |  |  | $ | 2 |
2024 | 356 |  |  | 2 |
2025 | 14 |  |  | 2 |
2026 | 14 |  |  | 2 |
2027 | 13 |  |  | 2 |
Fiscal years 2028 through 2032 | 59 |  |  | 11 |

Expected benefit payments are based on the same assumptions used to measure the benefit obligations and include estimated future employee service.
Plan Assets
The target allocations and weighted average asset allocations by asset category of the investment portfolio for the Company’s domestic retirement income plans as of June 30 were:

| % Target Allocation |  | % of Plan Assets
| 2022 |  | 2021 |  | 2022 |  | 2021
U.S. equity | — | % |  | 3 | % |  | — | % |  | 3 | %
International equity | — | % |  | 2 | % |  | — | % |  | 2 | %
Fixed income | 100 | % |  | 95 | % |  | 99 | % |  | 94 | %
Other | — | % |  | — | % |  | 1 | % |  | 1 | %
Total | 100 | % |  | 100 | % |  | 100 | % |  | 100 | %

The target asset allocation is determined based on the optimal balance between risk and return and, at times, may be adjusted to achieve the plan’s overall investment objective to generate sufficient resources to pay current and projected plan obligations over the life of the domestic retirement income plan.
58

NOTE 17. EMPLOYEE BENEFIT PLANS (Continued)
The following table sets forth the retirement income plans’ assets carried at fair value as of June 30:

|  | 2022 | 2021
Common collective trusts measured at net asset value |  |  |
Bond funds |  | $ | 391 |  | $ | 459 |
International equity funds |  | 14 |  | 28 |
Domestic equity funds |  | — |  | 14 |
Short-term investment fund |  | 4 |  | 3 |
Real estate fund |  | 3 |  | 2 |
Total assets at fair value |  | $ | 412 |  | $ | 506 |

Common collective trust funds are not publicly traded and were valued at a net asset value unit price determined by the portfolio’s sponsor based on the fair value of underlying assets held by the common collective trust fund on June 30, 2022 and 2021.
The common collective trusts are invested in various trusts that attempt to achieve their investment objectives by investing primarily in other collective investment funds that have characteristics consistent with each trust’s overall investment objective and strategy.
Defined Contribution Plans
The Company has various defined contribution plans for eligible domestic and international employees. The aggregate cost of the domestic defined contribution plans was $58, $65 and $54 in fiscal years 2022, 2021 and 2020, respectively. The aggregate cost of the international defined contribution plans was $6, $4 and $4 for the fiscal years ended June 30, 2022, 2021 and 2020, respectively.
NOTE 18. SEGMENT REPORTING
The Company operates through SBUs that are also the Company’s operating segments. These SBUs are then aggregated into four reportable segments: Health and Wellness, Household, Lifestyle and International. These four reportable segments consist of the following:
•Health and Wellness consists of cleaning products, professional products and vitamins, minerals and supplements mainly marketed and sold in the U.S.
•Household consists of bags and wraps, grilling products and cat litter marketed and sold in the U.S.
•Lifestyle consists of food, natural personal care products and water-filtration products marketed and sold in the U.S.
•International consists of products sold outside the U.S. Products within this segment include laundry additives; home care products; water-filtration products; digestive health products; grilling products; cat litter; food; bags and wraps; natural personal care products; and professional cleaning and disinfecting products.
59

NOTE 18. SEGMENT REPORTING (Continued)
Certain non-allocated administrative costs, interest income, interest expense and various other non-operating income and expenses are reflected in Corporate. Corporate assets include cash and cash equivalents, prepaid expenses and other current assets, property and equipment, operating lease right-of-use assets, other long-term assets and deferred taxes.

| Fiscal Year |  | Health and Wellness (1) |  | Household |  | Lifestyle |  | International (2) |  | Corporate (3) |  | Total Company
Net sales | 2022 |  | $ | 2,690 |  |  | $ | 1,984 |  |  | $ | 1,253 |  |  | $ | 1,180 |  |  | $ | — |  |  | $ | 7,107 |
| 2021 |  | 2,980 |  |  | 1,981 |  |  | 1,218 |  |  | 1,162 |  |  | — |  |  | 7,341 |
| 2020 |  | 2,749 |  |  | 1,795 |  |  | 1,154 |  |  | 1,023 |  |  | — |  |  | 6,721 |
Earnings (losses) before income taxes | 2022 |  | 300 |  |  | 234 |  |  | 280 |  |  | 97 |  |  | (304) |  |  | 607 |
| 2021 |  | 305 |  |  | 375 |  |  | 320 |  |  | 201 |  |  | (301) |  |  | 900 |
| 2020 |  | 766 |  |  | 347 |  |  | 320 |  |  | 116 |  |  | (364) |  |  | 1,185 |
Income from equity investees included in Other (income) expense, net | 2022 |  | — |  |  | — |  |  | — |  |  | 6 |  |  | — |  |  | 6 |
2021 |  | — |  |  | — |  |  | — |  |  | 5 |  |  | — |  |  | 5 |
| 2020 |  | — |  |  | — |  |  | — |  |  | 20 |  |  | — |  |  | 20 |
Total assets | 2022 |  | 1,999 |  |  | 1,045 |  |  | 1,035 |  |  | 1,453 |  |  | 626 |  |  | 6,158 |
| 2021 |  | 2,043 |  |  | 912 |  |  | 1,011 |  |  | 1,489 |  |  | 879 |  |  | 6,334 |
Capital expenditures | 2022 |  | 72 |  |  | 112 |  |  | 24 |  |  | 27 |  |  | 16 |  |  | 251 |
| 2021 |  | 135 |  |  | 108 |  |  | 29 |  |  | 42 |  |  | 17 |  |  | 331 |
| 2020 |  | 72 |  |  | 94 |  |  | 46 |  |  | 20 |  |  | 22 |  |  | 254 |
Depreciation and amortization | 2022 |  | 75 |  |  | 67 |  |  | 24 |  |  | 47 |  |  | 11 |  |  | 224 |
| 2021 |  | 67 |  |  | 67 |  |  | 23 |  |  | 45 |  |  | 9 |  |  | 211 |
| 2020 |  | 64 |  |  | 65 |  |  | 22 |  |  | 22 |  |  | 7 |  |  | 180 |
Significant non-cash charges included in earnings (losses) before income taxes:
Stock-based compensation | 2022 |  | 17 |  |  | 8 |  |  | 6 |  |  | 3 |  |  | 18 |  |  | 52 |
| 2021 |  | 19 |  |  | 10 |  |  | 7 |  |  | 2 |  |  | 12 |  |  | 50 |
| 2020 |  | 13 |  |  | 9 |  |  | 6 |  |  | 1 |  |  | 21 |  |  | 50 |

(1) Fiscal year 2021 earnings (losses) before income taxes for the Health and Wellness segment included impairment charges of $343, of which $228, $93, and $22 related to goodwill, certain indefinite-lived trademarks and other assets, respectively.
(2) Fiscal year 2021 earnings (losses) before income taxes for the International segment included an $85 non-cash gain from the remeasurement of the Company’s previously held investment in its Saudi joint venture.
(3) Fiscal year 2022 earnings (losses) before income taxes for the Corporate segment included expenses related to the Company's digital capabilities and productivity enhancements investment.
All intersegment sales are eliminated and are not included in the Company’s reportable segments’ net sales.
Net sales to the Company’s largest customer, Walmart Stores, Inc. and its affiliates, were 25% of consolidated net sales for each of the fiscal years ended June 30, 2022, 2021 and 2020, and occurred across all of the Company’s reportable segments. No other customers accounted for 10% or more of the Company’s consolidated net sales in any of these fiscal years.
60

NOTE 18. SEGMENT REPORTING (Continued)
The following table provides Net sales as a percentage of the Company’s consolidated net sales, disaggregated by SBU, for the fiscal years ended June 30:

|  | 2022 |  | 2021 |  | 2020
Cleaning |  | 29 | % |  | 30 | % |  | 30 | %
Professional Products |  | 4 | % |  | 7 | % |  | 7 | %
Vitamins, Minerals and Supplements |  | 4 | % |  | 4 | % |  | 4 | %
Health and Wellness |  | 37 | % |  | 41 | % |  | 41 | %
Bags and Wraps |  | 12 | % |  | 11 | % |  | 12 | %
Grilling |  | 8 | % |  | 9 | % |  | 8 | %
Cat Litter |  | 8 | % |  | 7 | % |  | 7 | %
Household |  | 28 | % |  | 27 | % |  | 27 | %
Food |  | 10 | % |  | 9 | % |  | 9 | %
Natural Personal Care |  | 4 | % |  | 4 | % |  | 4 | %
Water Filtration |  | 4 | % |  | 3 | % |  | 4 | %
Lifestyle |  | 18 | % |  | 16 | % |  | 17 | %
International |  | 17 | % |  | 16 | % |  | 15 | %
Total |  | 100 | % |  | 100 | % |  | 100 | %

The Company’s products are marketed and sold globally. The following table provides the Company’s global product lines, which were sold in the U.S. and International, that accounted for 10% or more of consolidated net sales for the fiscal years ended June 30:

| 2022 |  | 2021 |  | 2020
Cleaning products | 42 | % |  | 43 | % |  | 43 | %
Bags and wraps | 16 | % |  | 14 | % |  | 15 | %
Food products | 11 | % |  | 10 | % |  | 10 | %

Net sales and property, plant and equipment, net, by geographic area for and as of the fiscal years ended June 30 were as follows:

| Fiscal Year |  | United States |  | Foreign |  | Total Company
Net sales | 2022 |  | $ | 5,951 |  |  | $ | 1,156 |  |  | $ | 7,107 |
| 2021 |  | 6,207 |  |  | 1,134 |  |  | 7,341 |
| 2020 |  | 5,725 |  |  | 996 |  |  | 6,721 |
Property, plant and equipment, net | 2022 |  | 1,180 |  |  | 154 |  |  | 1,334 |
| 2021 |  | 1,143 |  |  | 159 |  |  | 1,302 |

NOTE 19. RELATED PARTY TRANSACTIONS
The Company holds various equity investments with ownership percentages of up to 50% in a number of consumer products businesses, which operate both within and outside the United States. The equity investments, presented in Other assets and accounted for under the equity method, were $52 and $55 as of the fiscal years ended June 30, 2022 and 2021, respectively. The Company has no ongoing capital commitments, loan requirements, guarantees or any other types of arrangements under the terms of its agreements that would require any future cash contributions or disbursements arising out of an equity investment.
Transactions with the Company’s equity investees typically represent payments for contract manufacturing and purchases of raw materials. Payments to related parties, including equity investees, for such transactions during the fiscal years ended June 30, 2022, 2021 and 2020 were $117, $44 and $55, respectively. Receipts from and ending accounts receivable and payable balances related to the Company’s related parties were not significant during or as of the end of each of the fiscal years presented.
61

NOTE 20. SUBSEQUENT EVENT
On August 3, 2022, the Company announced it will begin to implement a streamlined operating model in the first quarter of fiscal year 2023. The Company’s Board of Directors has approved up to approximately $100 of expenses to be incurred over fiscal years 2023 and 2024 related to this initiative, including restructuring costs, primarily employee-related costs, as well as associated implementation and other costs. The costs are expected to be recorded primarily within Other (income) expense, net.
62